/****************************************************************************
** Meta object code from reading C++ file 'singleviewwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/okteta-17.08.3/libs/kasten/gui/shell/singleviewwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'singleviewwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__SingleViewWindow_t {
    QByteArrayData data[14];
    char stringdata0[231];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__SingleViewWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__SingleViewWindow_t qt_meta_stringdata_Kasten__SingleViewWindow = {
    {
QT_MOC_LITERAL(0, 0, 24), // "Kasten::SingleViewWindow"
QT_MOC_LITERAL(1, 25, 14), // "onTitleChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 8), // "newTitle"
QT_MOC_LITERAL(4, 50, 21), // "onContentFlagsChanged"
QT_MOC_LITERAL(5, 72, 20), // "Kasten::ContentFlags"
QT_MOC_LITERAL(6, 93, 12), // "contentFlags"
QT_MOC_LITERAL(7, 106, 23), // "onLocalSyncStateChanged"
QT_MOC_LITERAL(8, 130, 22), // "Kasten::LocalSyncState"
QT_MOC_LITERAL(9, 153, 8), // "newState"
QT_MOC_LITERAL(10, 162, 23), // "onToolVisibilityChanged"
QT_MOC_LITERAL(11, 186, 9), // "isVisible"
QT_MOC_LITERAL(12, 196, 21), // "onSynchronizerDeleted"
QT_MOC_LITERAL(13, 218, 12) // "synchronizer"

    },
    "Kasten::SingleViewWindow\0onTitleChanged\0"
    "\0newTitle\0onContentFlagsChanged\0"
    "Kasten::ContentFlags\0contentFlags\0"
    "onLocalSyncStateChanged\0Kasten::LocalSyncState\0"
    "newState\0onToolVisibilityChanged\0"
    "isVisible\0onSynchronizerDeleted\0"
    "synchronizer"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__SingleViewWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x08 /* Private */,
       4,    1,   42,    2, 0x08 /* Private */,
       7,    1,   45,    2, 0x08 /* Private */,
      10,    1,   48,    2, 0x08 /* Private */,
      12,    1,   51,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void, QMetaType::QObjectStar,   13,

       0        // eod
};

void Kasten::SingleViewWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SingleViewWindow *_t = static_cast<SingleViewWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->d_func()->onTitleChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->d_func()->onContentFlagsChanged((*reinterpret_cast< Kasten::ContentFlags(*)>(_a[1]))); break;
        case 2: _t->d_func()->onLocalSyncStateChanged((*reinterpret_cast< Kasten::LocalSyncState(*)>(_a[1]))); break;
        case 3: _t->d_func()->onToolVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->d_func()->onSynchronizerDeleted((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::SingleViewWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_Kasten__SingleViewWindow.data,
      qt_meta_data_Kasten__SingleViewWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::SingleViewWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::SingleViewWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__SingleViewWindow.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "If::WidgetsDockable"))
        return static_cast< If::WidgetsDockable*>(this);
    if (!strcmp(_clname, "org.kde.kasten.if.widgetsdockable/1.0"))
        return static_cast< Kasten::If::WidgetsDockable*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Kasten::SingleViewWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
