/*
 *   This file is part of the Okteta Kasten Framework, made within the KDE community.
 *
 *   Copyright 2012 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include "bitfieldscriptclass.h"
#include "../../datatypes/primitive/bitfield/abstractbitfielddatainformation.h"
#include "../../parsers/parserutils.h"

BitfieldScriptClass::BitfieldScriptClass(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo)
: PrimitiveScriptClass(engine, handlerInfo)
{
    s_width = engine->toStringHandle(ParserStrings::PROPERTY_WIDTH());
    mIterableProperties.append(qMakePair(s_width, QScriptValue::PropertyFlags(QScriptValue::Undeletable)));
}

BitfieldScriptClass::~BitfieldScriptClass()
{
}

QScriptValue BitfieldScriptClass::additionalProperty(const DataInformation* data, const QScriptString& name, uint id)
{
    const AbstractBitfieldDataInformation* pData = data->asBitfield();
    if (name == s_width)
    {
        return pData->width();
    }
    else if (name == s_type)
    {
        return pData->typeName();
    }
    return PrimitiveScriptClass::additionalProperty(data, name, id);
}

bool BitfieldScriptClass::queryAdditionalProperty(const DataInformation* data, const QScriptString& name, QScriptClass::QueryFlags* flags, uint* id)
{
    if (name == s_width)
    {
        *flags = QScriptClass::HandlesReadAccess | QScriptClass::HandlesWriteAccess;
        return true;
    }
    return PrimitiveScriptClass::queryAdditionalProperty(data, name, flags, id);
}

bool BitfieldScriptClass::setAdditionalProperty(DataInformation* data, const QScriptString& name, uint id, const QScriptValue& value)
{
    if (name == s_width)
    {
        if (!value.isNumber())
        {
            engine()->currentContext()->throwError(QScriptContext::TypeError, QStringLiteral("bitfield.width must be an integer!"));
            return true;
        }
        BitCount32 width = value.toUInt32();
        if (width <= 0 || width > 64)
        {
            engine()->currentContext()->throwError(QScriptContext::RangeError,
                    QString(QStringLiteral("bitfield.width must be between 1 and 64! Given: %1")).arg(width));
            return true;
        }
        AbstractBitfieldDataInformation* pData = data->asBitfield();
        pData->setWidth(width);
        return true;
    }
    return PrimitiveScriptClass::setAdditionalProperty(data, name, id, value);
}
