/****************************************************************************
** Meta object code from reading C++ file 'stringsextracttool.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/stringsextract/stringsextracttool.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'stringsextracttool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__StringsExtractTool_t {
    QByteArrayData data[20];
    char stringdata0[310];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__StringsExtractTool_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__StringsExtractTool_t qt_meta_stringdata_Kasten__StringsExtractTool = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Kasten::StringsExtractTool"
QT_MOC_LITERAL(1, 27, 15), // "uptodateChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 10), // "isUptodate"
QT_MOC_LITERAL(4, 55, 18), // "isApplyableChanged"
QT_MOC_LITERAL(5, 74, 11), // "isApplyable"
QT_MOC_LITERAL(6, 86, 25), // "canHighlightStringChanged"
QT_MOC_LITERAL(7, 112, 18), // "canHighlightString"
QT_MOC_LITERAL(8, 131, 19), // "offsetCodingChanged"
QT_MOC_LITERAL(9, 151, 12), // "offsetCoding"
QT_MOC_LITERAL(10, 164, 12), // "setMinLength"
QT_MOC_LITERAL(11, 177, 9), // "minLength"
QT_MOC_LITERAL(12, 187, 10), // "markString"
QT_MOC_LITERAL(13, 198, 8), // "stringId"
QT_MOC_LITERAL(14, 207, 12), // "unmarkString"
QT_MOC_LITERAL(15, 220, 14), // "extractStrings"
QT_MOC_LITERAL(16, 235, 18), // "onSelectionChanged"
QT_MOC_LITERAL(17, 254, 15), // "onSourceChanged"
QT_MOC_LITERAL(18, 270, 17), // "onSourceDestroyed"
QT_MOC_LITERAL(19, 288, 21) // "onSourceViewDestroyed"

    },
    "Kasten::StringsExtractTool\0uptodateChanged\0"
    "\0isUptodate\0isApplyableChanged\0"
    "isApplyable\0canHighlightStringChanged\0"
    "canHighlightString\0offsetCodingChanged\0"
    "offsetCoding\0setMinLength\0minLength\0"
    "markString\0stringId\0unmarkString\0"
    "extractStrings\0onSelectionChanged\0"
    "onSourceChanged\0onSourceDestroyed\0"
    "onSourceViewDestroyed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__StringsExtractTool[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       4,    1,   77,    2, 0x06 /* Public */,
       6,    1,   80,    2, 0x06 /* Public */,
       8,    1,   83,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,   86,    2, 0x0a /* Public */,
      12,    1,   89,    2, 0x0a /* Public */,
      14,    0,   92,    2, 0x0a /* Public */,
      15,    0,   93,    2, 0x0a /* Public */,
      16,    0,   94,    2, 0x08 /* Private */,
      17,    0,   95,    2, 0x08 /* Private */,
      18,    0,   96,    2, 0x08 /* Private */,
      19,    0,   97,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Int,    9,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Kasten::StringsExtractTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StringsExtractTool *_t = static_cast<StringsExtractTool *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->uptodateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->isApplyableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->canHighlightStringChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->offsetCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->setMinLength((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->markString((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->unmarkString(); break;
        case 7: _t->extractStrings(); break;
        case 8: _t->onSelectionChanged(); break;
        case 9: _t->onSourceChanged(); break;
        case 10: _t->onSourceDestroyed(); break;
        case 11: _t->onSourceViewDestroyed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (StringsExtractTool::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StringsExtractTool::uptodateChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (StringsExtractTool::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StringsExtractTool::isApplyableChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (StringsExtractTool::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StringsExtractTool::canHighlightStringChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (StringsExtractTool::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StringsExtractTool::offsetCodingChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject Kasten::StringsExtractTool::staticMetaObject = {
    { &AbstractTool::staticMetaObject, qt_meta_stringdata_Kasten__StringsExtractTool.data,
      qt_meta_data_Kasten__StringsExtractTool,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::StringsExtractTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::StringsExtractTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__StringsExtractTool.stringdata0))
        return static_cast<void*>(this);
    return AbstractTool::qt_metacast(_clname);
}

int Kasten::StringsExtractTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTool::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Kasten::StringsExtractTool::uptodateChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::StringsExtractTool::isApplyableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kasten::StringsExtractTool::canHighlightStringChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kasten::StringsExtractTool::offsetCodingChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
