/****************************************************************************
** Meta object code from reading C++ file 'selectrangetool.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/selectrange/selectrangetool.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'selectrangetool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__SelectRangeTool_t {
    QByteArrayData data[17];
    char stringdata0[224];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__SelectRangeTool_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__SelectRangeTool_t qt_meta_stringdata_Kasten__SelectRangeTool = {
    {
QT_MOC_LITERAL(0, 0, 23), // "Kasten::SelectRangeTool"
QT_MOC_LITERAL(1, 24, 15), // "isUsableChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 8), // "isUsable"
QT_MOC_LITERAL(4, 50, 18), // "isApplyableChanged"
QT_MOC_LITERAL(5, 69, 11), // "isApplyable"
QT_MOC_LITERAL(6, 81, 14), // "setTargetStart"
QT_MOC_LITERAL(7, 96, 15), // "Okteta::Address"
QT_MOC_LITERAL(8, 112, 5), // "start"
QT_MOC_LITERAL(9, 118, 12), // "setTargetEnd"
QT_MOC_LITERAL(10, 131, 3), // "end"
QT_MOC_LITERAL(11, 135, 16), // "setIsEndRelative"
QT_MOC_LITERAL(12, 152, 13), // "isEndRelative"
QT_MOC_LITERAL(13, 166, 17), // "setIsEndBackwards"
QT_MOC_LITERAL(14, 184, 14), // "isEndBackwards"
QT_MOC_LITERAL(15, 199, 6), // "select"
QT_MOC_LITERAL(16, 206, 17) // "onContentsChanged"

    },
    "Kasten::SelectRangeTool\0isUsableChanged\0"
    "\0isUsable\0isApplyableChanged\0isApplyable\0"
    "setTargetStart\0Okteta::Address\0start\0"
    "setTargetEnd\0end\0setIsEndRelative\0"
    "isEndRelative\0setIsEndBackwards\0"
    "isEndBackwards\0select\0onContentsChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__SelectRangeTool[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    1,   57,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   60,    2, 0x0a /* Public */,
       9,    1,   63,    2, 0x0a /* Public */,
      11,    1,   66,    2, 0x0a /* Public */,
      13,    1,   69,    2, 0x0a /* Public */,
      15,    0,   72,    2, 0x0a /* Public */,
      16,    0,   73,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    5,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Kasten::SelectRangeTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SelectRangeTool *_t = static_cast<SelectRangeTool *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->isUsableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->isApplyableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setTargetStart((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        case 3: _t->setTargetEnd((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        case 4: _t->setIsEndRelative((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->setIsEndBackwards((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->select(); break;
        case 7: _t->onContentsChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (SelectRangeTool::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SelectRangeTool::isUsableChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SelectRangeTool::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SelectRangeTool::isApplyableChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Kasten::SelectRangeTool::staticMetaObject = {
    { &AbstractTool::staticMetaObject, qt_meta_stringdata_Kasten__SelectRangeTool.data,
      qt_meta_data_Kasten__SelectRangeTool,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::SelectRangeTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::SelectRangeTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__SelectRangeTool.stringdata0))
        return static_cast<void*>(this);
    return AbstractTool::qt_metacast(_clname);
}

int Kasten::SelectRangeTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTool::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Kasten::SelectRangeTool::isUsableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::SelectRangeTool::isApplyableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
