// This file is generated by kconfig_compiler_kf5 from bytetableviewsettings.kcfg.
// All changes you do to this file will be lost.

#include "bytetableviewsettings.h"

#include <klocalizedstring.h>

#include <qglobal.h>
#include <QtCore/QFile>

using namespace Kasten;

namespace Kasten {

class ByteTableViewSettingsHelper
{
  public:
    ByteTableViewSettingsHelper() : q(nullptr) {}
    ~ByteTableViewSettingsHelper() { delete q; }
    ByteTableViewSettings *q;
};
}

Q_GLOBAL_STATIC(ByteTableViewSettingsHelper, s_globalByteTableViewSettings)
ByteTableViewSettings *ByteTableViewSettings::self()
{
  if (!s_globalByteTableViewSettings()->q) {
    new ByteTableViewSettings;
    s_globalByteTableViewSettings()->q->read();
  }

  return s_globalByteTableViewSettings()->q;
}

ByteTableViewSettings::ByteTableViewSettings(  )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalByteTableViewSettings()->q);
  s_globalByteTableViewSettings()->q = this;
  setCurrentGroup( QStringLiteral( "ByteTableView" ) );

  QList<int> defaultColumnsWidth;

  KConfigSkeleton::ItemIntList  *itemColumnsWidth;
  itemColumnsWidth = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "ColumnsWidth" ), mColumnsWidth, defaultColumnsWidth );
  itemColumnsWidth->setLabel( i18nd("liboktetakasten", "ColumnsWidth") );
  addItem( itemColumnsWidth, QStringLiteral( "ColumnsWidth" ) );
  KConfigSkeleton::ItemString  *itemStyle;
  itemStyle = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Style" ), mStyle );
  itemStyle->setLabel( i18nd("liboktetakasten", "Style") );
  addItem( itemStyle, QStringLiteral( "Style" ) );
  KConfigSkeleton::ItemString  *itemFixedFont;
  itemFixedFont = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "FixedFont" ), mFixedFont );
  itemFixedFont->setLabel( i18nd("liboktetakasten", "FixedFont") );
  addItem( itemFixedFont, QStringLiteral( "FixedFont" ) );
}

ByteTableViewSettings::~ByteTableViewSettings()
{
  s_globalByteTableViewSettings()->q = nullptr;
}

