/****************************************************************************
** Meta object code from reading C++ file 'viewprofilecontroller.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/viewprofiles/viewprofilecontroller.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewprofilecontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__ViewProfileController_t {
    QByteArrayData data[15];
    char stringdata0[308];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__ViewProfileController_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__ViewProfileController_t qt_meta_stringdata_Kasten__ViewProfileController = {
    {
QT_MOC_LITERAL(0, 0, 29), // "Kasten::ViewProfileController"
QT_MOC_LITERAL(1, 30, 20), // "onViewProfileChanged"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 32), // "Kasten::ByteArrayViewProfile::Id"
QT_MOC_LITERAL(4, 85, 13), // "viewProfileId"
QT_MOC_LITERAL(5, 99, 23), // "onLocalSyncStateChanged"
QT_MOC_LITERAL(6, 123, 22), // "Kasten::LocalSyncState"
QT_MOC_LITERAL(7, 146, 14), // "localSyncState"
QT_MOC_LITERAL(8, 161, 21), // "onViewProfilesChanged"
QT_MOC_LITERAL(9, 183, 26), // "onCreateNewActionTriggered"
QT_MOC_LITERAL(10, 210, 29), // "onResetChangesActionTriggered"
QT_MOC_LITERAL(11, 240, 28), // "onSaveChangesActionTriggered"
QT_MOC_LITERAL(12, 269, 22), // "onViewProfileTriggered"
QT_MOC_LITERAL(13, 292, 8), // "QAction*"
QT_MOC_LITERAL(14, 301, 6) // "action"

    },
    "Kasten::ViewProfileController\0"
    "onViewProfileChanged\0\0"
    "Kasten::ByteArrayViewProfile::Id\0"
    "viewProfileId\0onLocalSyncStateChanged\0"
    "Kasten::LocalSyncState\0localSyncState\0"
    "onViewProfilesChanged\0onCreateNewActionTriggered\0"
    "onResetChangesActionTriggered\0"
    "onSaveChangesActionTriggered\0"
    "onViewProfileTriggered\0QAction*\0action"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__ViewProfileController[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x08 /* Private */,
       5,    1,   52,    2, 0x08 /* Private */,
       8,    0,   55,    2, 0x08 /* Private */,
       9,    0,   56,    2, 0x08 /* Private */,
      10,    0,   57,    2, 0x08 /* Private */,
      11,    0,   58,    2, 0x08 /* Private */,
      12,    1,   59,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,

       0        // eod
};

void Kasten::ViewProfileController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ViewProfileController *_t = static_cast<ViewProfileController *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onViewProfileChanged((*reinterpret_cast< const Kasten::ByteArrayViewProfile::Id(*)>(_a[1]))); break;
        case 1: _t->onLocalSyncStateChanged((*reinterpret_cast< Kasten::LocalSyncState(*)>(_a[1]))); break;
        case 2: _t->onViewProfilesChanged(); break;
        case 3: _t->onCreateNewActionTriggered(); break;
        case 4: _t->onResetChangesActionTriggered(); break;
        case 5: _t->onSaveChangesActionTriggered(); break;
        case 6: _t->onViewProfileTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::ViewProfileController::staticMetaObject = {
    { &AbstractXmlGuiController::staticMetaObject, qt_meta_stringdata_Kasten__ViewProfileController.data,
      qt_meta_data_Kasten__ViewProfileController,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::ViewProfileController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::ViewProfileController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__ViewProfileController.stringdata0))
        return static_cast<void*>(this);
    return AbstractXmlGuiController::qt_metacast(_clname);
}

int Kasten::ViewProfileController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractXmlGuiController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
