/****************************************************************************
** Meta object code from reading C++ file 'bookmarkscontroller.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/bookmarks/bookmarkscontroller.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bookmarkscontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__BookmarksController_t {
    QByteArrayData data[17];
    char stringdata0[283];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__BookmarksController_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__BookmarksController_t qt_meta_stringdata_Kasten__BookmarksController = {
    {
QT_MOC_LITERAL(0, 0, 27), // "Kasten::BookmarksController"
QT_MOC_LITERAL(1, 28, 14), // "createBookmark"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 14), // "deleteBookmark"
QT_MOC_LITERAL(4, 59, 18), // "deleteAllBookmarks"
QT_MOC_LITERAL(5, 78, 16), // "gotoNextBookmark"
QT_MOC_LITERAL(6, 95, 20), // "gotoPreviousBookmark"
QT_MOC_LITERAL(7, 116, 15), // "updateBookmarks"
QT_MOC_LITERAL(8, 132, 19), // "onBookmarkTriggered"
QT_MOC_LITERAL(9, 152, 8), // "QAction*"
QT_MOC_LITERAL(10, 161, 16), // "onBookmarksAdded"
QT_MOC_LITERAL(11, 178, 23), // "QList<Okteta::Bookmark>"
QT_MOC_LITERAL(12, 202, 9), // "bookmarks"
QT_MOC_LITERAL(13, 212, 18), // "onBookmarksRemoved"
QT_MOC_LITERAL(14, 231, 23), // "onCursorPositionChanged"
QT_MOC_LITERAL(15, 255, 15), // "Okteta::Address"
QT_MOC_LITERAL(16, 271, 11) // "newPosition"

    },
    "Kasten::BookmarksController\0createBookmark\0"
    "\0deleteBookmark\0deleteAllBookmarks\0"
    "gotoNextBookmark\0gotoPreviousBookmark\0"
    "updateBookmarks\0onBookmarkTriggered\0"
    "QAction*\0onBookmarksAdded\0"
    "QList<Okteta::Bookmark>\0bookmarks\0"
    "onBookmarksRemoved\0onCursorPositionChanged\0"
    "Okteta::Address\0newPosition"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__BookmarksController[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x08 /* Private */,
       3,    0,   65,    2, 0x08 /* Private */,
       4,    0,   66,    2, 0x08 /* Private */,
       5,    0,   67,    2, 0x08 /* Private */,
       6,    0,   68,    2, 0x08 /* Private */,
       7,    0,   69,    2, 0x08 /* Private */,
       8,    1,   70,    2, 0x08 /* Private */,
      10,    1,   73,    2, 0x08 /* Private */,
      13,    1,   76,    2, 0x08 /* Private */,
      14,    1,   79,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, 0x80000000 | 15,   16,

       0        // eod
};

void Kasten::BookmarksController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        BookmarksController *_t = static_cast<BookmarksController *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->createBookmark(); break;
        case 1: _t->deleteBookmark(); break;
        case 2: _t->deleteAllBookmarks(); break;
        case 3: _t->gotoNextBookmark(); break;
        case 4: _t->gotoPreviousBookmark(); break;
        case 5: _t->updateBookmarks(); break;
        case 6: _t->onBookmarkTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 7: _t->onBookmarksAdded((*reinterpret_cast< const QList<Okteta::Bookmark>(*)>(_a[1]))); break;
        case 8: _t->onBookmarksRemoved((*reinterpret_cast< const QList<Okteta::Bookmark>(*)>(_a[1]))); break;
        case 9: _t->onCursorPositionChanged((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::BookmarksController::staticMetaObject = {
    { &AbstractXmlGuiController::staticMetaObject, qt_meta_stringdata_Kasten__BookmarksController.data,
      qt_meta_data_Kasten__BookmarksController,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::BookmarksController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::BookmarksController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__BookmarksController.stringdata0))
        return static_cast<void*>(this);
    return AbstractXmlGuiController::qt_metacast(_clname);
}

int Kasten::BookmarksController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractXmlGuiController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
