/****************************************************************************
** Meta object code from reading C++ file 'structview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/structures/structview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'structview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__StructView_t {
    QByteArrayData data[14];
    char stringdata0[226];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__StructView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__StructView_t qt_meta_stringdata_Kasten__StructView = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Kasten::StructView"
QT_MOC_LITERAL(1, 19, 15), // "openSettingsDlg"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 17), // "openScriptConsole"
QT_MOC_LITERAL(4, 54, 19), // "onCurrentRowChanged"
QT_MOC_LITERAL(5, 74, 7), // "current"
QT_MOC_LITERAL(6, 82, 8), // "previous"
QT_MOC_LITERAL(7, 91, 19), // "onCursorIndexChange"
QT_MOC_LITERAL(8, 111, 17), // "lockButtonToggled"
QT_MOC_LITERAL(9, 129, 18), // "setLockButtonState"
QT_MOC_LITERAL(10, 148, 15), // "structureLocked"
QT_MOC_LITERAL(11, 164, 23), // "onByteArrayModelChanged"
QT_MOC_LITERAL(12, 188, 31), // "Okteta::AbstractByteArrayModel*"
QT_MOC_LITERAL(13, 220, 5) // "model"

    },
    "Kasten::StructView\0openSettingsDlg\0\0"
    "openScriptConsole\0onCurrentRowChanged\0"
    "current\0previous\0onCursorIndexChange\0"
    "lockButtonToggled\0setLockButtonState\0"
    "structureLocked\0onByteArrayModelChanged\0"
    "Okteta::AbstractByteArrayModel*\0model"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__StructView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x09 /* Protected */,
       3,    0,   50,    2, 0x09 /* Protected */,
       4,    2,   51,    2, 0x09 /* Protected */,
       7,    0,   56,    2, 0x09 /* Protected */,
       8,    0,   57,    2, 0x09 /* Protected */,
       9,    1,   58,    2, 0x09 /* Protected */,
      11,    1,   61,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex, QMetaType::QModelIndex,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void, 0x80000000 | 12,   13,

       0        // eod
};

void Kasten::StructView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StructView *_t = static_cast<StructView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->openSettingsDlg(); break;
        case 1: _t->openScriptConsole(); break;
        case 2: _t->onCurrentRowChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 3: _t->onCursorIndexChange(); break;
        case 4: _t->lockButtonToggled(); break;
        case 5: _t->setLockButtonState((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->onByteArrayModelChanged((*reinterpret_cast< Okteta::AbstractByteArrayModel*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::StructView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Kasten__StructView.data,
      qt_meta_data_Kasten__StructView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::StructView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::StructView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__StructView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Kasten::StructView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
