/****************************************************************************
** Meta object code from reading C++ file 'piecetablebytearraymodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/okteta-17.08.3/core/piecetablebytearraymodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'piecetablebytearraymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Okteta__PieceTableByteArrayModel_t {
    QByteArrayData data[21];
    char stringdata0[353];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Okteta__PieceTableByteArrayModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Okteta__PieceTableByteArrayModel_t qt_meta_stringdata_Okteta__PieceTableByteArrayModel = {
    {
QT_MOC_LITERAL(0, 0, 32), // "Okteta::PieceTableByteArrayModel"
QT_MOC_LITERAL(1, 33, 22), // "revertedToVersionIndex"
QT_MOC_LITERAL(2, 56, 0), // ""
QT_MOC_LITERAL(3, 57, 12), // "versionIndex"
QT_MOC_LITERAL(4, 70, 29), // "headVersionDescriptionChanged"
QT_MOC_LITERAL(5, 100, 18), // "versionDescription"
QT_MOC_LITERAL(6, 119, 18), // "headVersionChanged"
QT_MOC_LITERAL(7, 138, 19), // "newHeadVersionIndex"
QT_MOC_LITERAL(8, 158, 14), // "bookmarksAdded"
QT_MOC_LITERAL(9, 173, 23), // "QList<Okteta::Bookmark>"
QT_MOC_LITERAL(10, 197, 9), // "bookmarks"
QT_MOC_LITERAL(11, 207, 16), // "bookmarksRemoved"
QT_MOC_LITERAL(12, 224, 17), // "bookmarksModified"
QT_MOC_LITERAL(13, 242, 8), // "modified"
QT_MOC_LITERAL(14, 251, 10), // "QList<int>"
QT_MOC_LITERAL(15, 262, 7), // "indizes"
QT_MOC_LITERAL(16, 270, 11), // "changesDone"
QT_MOC_LITERAL(17, 282, 30), // "QList<Okteta::ByteArrayChange>"
QT_MOC_LITERAL(18, 313, 7), // "changes"
QT_MOC_LITERAL(19, 321, 15), // "oldVersionIndex"
QT_MOC_LITERAL(20, 337, 15) // "newVersionIndex"

    },
    "Okteta::PieceTableByteArrayModel\0"
    "revertedToVersionIndex\0\0versionIndex\0"
    "headVersionDescriptionChanged\0"
    "versionDescription\0headVersionChanged\0"
    "newHeadVersionIndex\0bookmarksAdded\0"
    "QList<Okteta::Bookmark>\0bookmarks\0"
    "bookmarksRemoved\0bookmarksModified\0"
    "modified\0QList<int>\0indizes\0changesDone\0"
    "QList<Okteta::ByteArrayChange>\0changes\0"
    "oldVersionIndex\0newVersionIndex"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Okteta__PieceTableByteArrayModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    1,   57,    2, 0x06 /* Public */,
       6,    1,   60,    2, 0x06 /* Public */,
       8,    1,   63,    2, 0x06 /* Public */,
      11,    1,   66,    2, 0x06 /* Public */,
      12,    1,   69,    2, 0x06 /* Public */,
      12,    1,   72,    2, 0x06 /* Public */,
      16,    3,   75,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 17, QMetaType::Int, QMetaType::Int,   18,   19,   20,

       0        // eod
};

void Okteta::PieceTableByteArrayModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PieceTableByteArrayModel *_t = static_cast<PieceTableByteArrayModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->revertedToVersionIndex((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->headVersionDescriptionChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->headVersionChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->bookmarksAdded((*reinterpret_cast< const QList<Okteta::Bookmark>(*)>(_a[1]))); break;
        case 4: _t->bookmarksRemoved((*reinterpret_cast< const QList<Okteta::Bookmark>(*)>(_a[1]))); break;
        case 5: _t->bookmarksModified((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->bookmarksModified((*reinterpret_cast< const QList<int>(*)>(_a[1]))); break;
        case 7: _t->changesDone((*reinterpret_cast< const QList<Okteta::ByteArrayChange>(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (PieceTableByteArrayModel::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PieceTableByteArrayModel::revertedToVersionIndex)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (PieceTableByteArrayModel::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PieceTableByteArrayModel::headVersionDescriptionChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (PieceTableByteArrayModel::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PieceTableByteArrayModel::headVersionChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (PieceTableByteArrayModel::*_t)(const QList<Okteta::Bookmark> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PieceTableByteArrayModel::bookmarksAdded)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (PieceTableByteArrayModel::*_t)(const QList<Okteta::Bookmark> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PieceTableByteArrayModel::bookmarksRemoved)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (PieceTableByteArrayModel::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PieceTableByteArrayModel::bookmarksModified)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (PieceTableByteArrayModel::*_t)(const QList<int> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PieceTableByteArrayModel::bookmarksModified)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (PieceTableByteArrayModel::*_t)(const QList<Okteta::ByteArrayChange> & , int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PieceTableByteArrayModel::changesDone)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject Okteta::PieceTableByteArrayModel::staticMetaObject = {
    { &AbstractByteArrayModel::staticMetaObject, qt_meta_stringdata_Okteta__PieceTableByteArrayModel.data,
      qt_meta_data_Okteta__PieceTableByteArrayModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Okteta::PieceTableByteArrayModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Okteta::PieceTableByteArrayModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Okteta__PieceTableByteArrayModel.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Versionable"))
        return static_cast< Versionable*>(this);
    if (!strcmp(_clname, "Bookmarkable"))
        return static_cast< Bookmarkable*>(this);
    if (!strcmp(_clname, "ChangesDescribable"))
        return static_cast< ChangesDescribable*>(this);
    if (!strcmp(_clname, "ChangeHistory"))
        return static_cast< ChangeHistory*>(this);
    if (!strcmp(_clname, "org.kde.khecore.versionable/1.0"))
        return static_cast< Okteta::Versionable*>(this);
    if (!strcmp(_clname, "org.kde.khecore.bookmarkable/1.0"))
        return static_cast< Okteta::Bookmarkable*>(this);
    if (!strcmp(_clname, "org.kde.khecore.changesdescribable/1.0"))
        return static_cast< Okteta::ChangesDescribable*>(this);
    if (!strcmp(_clname, "org.kde.khecore.changehistory/1.0"))
        return static_cast< Okteta::ChangeHistory*>(this);
    return AbstractByteArrayModel::qt_metacast(_clname);
}

int Okteta::PieceTableByteArrayModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractByteArrayModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Okteta::PieceTableByteArrayModel::revertedToVersionIndex(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Okteta::PieceTableByteArrayModel::headVersionDescriptionChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Okteta::PieceTableByteArrayModel::headVersionChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Okteta::PieceTableByteArrayModel::bookmarksAdded(const QList<Okteta::Bookmark> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Okteta::PieceTableByteArrayModel::bookmarksRemoved(const QList<Okteta::Bookmark> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Okteta::PieceTableByteArrayModel::bookmarksModified(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Okteta::PieceTableByteArrayModel::bookmarksModified(const QList<int> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Okteta::PieceTableByteArrayModel::changesDone(const QList<Okteta::ByteArrayChange> & _t1, int _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
