/****************************************************************************
** Meta object code from reading C++ file 'bytearrayviewprofilemanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/gui/system/bytearrayviewprofilemanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bytearrayviewprofilemanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__ByteArrayViewProfileManager_t {
    QByteArrayData data[16];
    char stringdata0[355];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__ByteArrayViewProfileManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__ByteArrayViewProfileManager_t qt_meta_stringdata_Kasten__ByteArrayViewProfileManager = {
    {
QT_MOC_LITERAL(0, 0, 35), // "Kasten::ByteArrayViewProfileM..."
QT_MOC_LITERAL(1, 36, 19), // "viewProfilesChanged"
QT_MOC_LITERAL(2, 56, 0), // ""
QT_MOC_LITERAL(3, 57, 35), // "QList<Kasten::ByteArrayViewPr..."
QT_MOC_LITERAL(4, 93, 12), // "viewProfiles"
QT_MOC_LITERAL(5, 106, 19), // "viewProfilesRemoved"
QT_MOC_LITERAL(6, 126, 39), // "QList<Kasten::ByteArrayViewPr..."
QT_MOC_LITERAL(7, 166, 14), // "viewProfileIds"
QT_MOC_LITERAL(8, 181, 25), // "defaultViewProfileChanged"
QT_MOC_LITERAL(9, 207, 32), // "Kasten::ByteArrayViewProfile::Id"
QT_MOC_LITERAL(10, 240, 13), // "viewProfileId"
QT_MOC_LITERAL(11, 254, 18), // "viewProfilesLocked"
QT_MOC_LITERAL(12, 273, 20), // "viewProfilesUnlocked"
QT_MOC_LITERAL(13, 294, 27), // "onViewProfilesFolderChanged"
QT_MOC_LITERAL(14, 322, 4), // "path"
QT_MOC_LITERAL(15, 327, 27) // "onDefaultViewProfileChanged"

    },
    "Kasten::ByteArrayViewProfileManager\0"
    "viewProfilesChanged\0\0"
    "QList<Kasten::ByteArrayViewProfile>\0"
    "viewProfiles\0viewProfilesRemoved\0"
    "QList<Kasten::ByteArrayViewProfile::Id>\0"
    "viewProfileIds\0defaultViewProfileChanged\0"
    "Kasten::ByteArrayViewProfile::Id\0"
    "viewProfileId\0viewProfilesLocked\0"
    "viewProfilesUnlocked\0onViewProfilesFolderChanged\0"
    "path\0onDefaultViewProfileChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__ByteArrayViewProfileManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       5,    1,   52,    2, 0x06 /* Public */,
       8,    1,   55,    2, 0x06 /* Public */,
      11,    1,   58,    2, 0x06 /* Public */,
      12,    1,   61,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    1,   64,    2, 0x08 /* Private */,
      15,    1,   67,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6,    7,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::QString,   14,

       0        // eod
};

void Kasten::ByteArrayViewProfileManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ByteArrayViewProfileManager *_t = static_cast<ByteArrayViewProfileManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->viewProfilesChanged((*reinterpret_cast< const QList<Kasten::ByteArrayViewProfile>(*)>(_a[1]))); break;
        case 1: _t->viewProfilesRemoved((*reinterpret_cast< const QList<Kasten::ByteArrayViewProfile::Id>(*)>(_a[1]))); break;
        case 2: _t->defaultViewProfileChanged((*reinterpret_cast< const Kasten::ByteArrayViewProfile::Id(*)>(_a[1]))); break;
        case 3: _t->viewProfilesLocked((*reinterpret_cast< const QList<Kasten::ByteArrayViewProfile::Id>(*)>(_a[1]))); break;
        case 4: _t->viewProfilesUnlocked((*reinterpret_cast< const QList<Kasten::ByteArrayViewProfile::Id>(*)>(_a[1]))); break;
        case 5: _t->onViewProfilesFolderChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->onDefaultViewProfileChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ByteArrayViewProfileManager::*_t)(const QList<Kasten::ByteArrayViewProfile> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayViewProfileManager::viewProfilesChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ByteArrayViewProfileManager::*_t)(const QList<Kasten::ByteArrayViewProfile::Id> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayViewProfileManager::viewProfilesRemoved)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ByteArrayViewProfileManager::*_t)(const Kasten::ByteArrayViewProfile::Id & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayViewProfileManager::defaultViewProfileChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ByteArrayViewProfileManager::*_t)(const QList<Kasten::ByteArrayViewProfile::Id> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayViewProfileManager::viewProfilesLocked)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ByteArrayViewProfileManager::*_t)(const QList<Kasten::ByteArrayViewProfile::Id> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayViewProfileManager::viewProfilesUnlocked)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject Kasten::ByteArrayViewProfileManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Kasten__ByteArrayViewProfileManager.data,
      qt_meta_data_Kasten__ByteArrayViewProfileManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::ByteArrayViewProfileManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::ByteArrayViewProfileManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__ByteArrayViewProfileManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kasten::ByteArrayViewProfileManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Kasten::ByteArrayViewProfileManager::viewProfilesChanged(const QList<Kasten::ByteArrayViewProfile> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::ByteArrayViewProfileManager::viewProfilesRemoved(const QList<Kasten::ByteArrayViewProfile::Id> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kasten::ByteArrayViewProfileManager::defaultViewProfileChanged(const Kasten::ByteArrayViewProfile::Id & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kasten::ByteArrayViewProfileManager::viewProfilesLocked(const QList<Kasten::ByteArrayViewProfile::Id> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Kasten::ByteArrayViewProfileManager::viewProfilesUnlocked(const QList<Kasten::ByteArrayViewProfile::Id> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
