/****************************************************************************
** Meta object code from reading C++ file 'structtool.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/structures/structtool.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'structtool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__StructTool_t {
    QByteArrayData data[39];
    char stringdata0[578];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__StructTool_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__StructTool_t qt_meta_stringdata_Kasten__StructTool = {
    {
QT_MOC_LITERAL(0, 0, 18), // "Kasten::StructTool"
QT_MOC_LITERAL(1, 19, 11), // "dataChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 3), // "row"
QT_MOC_LITERAL(4, 36, 4), // "data"
QT_MOC_LITERAL(5, 41, 11), // "dataCleared"
QT_MOC_LITERAL(6, 53, 16), // "byteOrderChanged"
QT_MOC_LITERAL(7, 70, 18), // "cursorIndexChanged"
QT_MOC_LITERAL(8, 89, 21), // "byteArrayModelChanged"
QT_MOC_LITERAL(9, 111, 31), // "Okteta::AbstractByteArrayModel*"
QT_MOC_LITERAL(10, 143, 5), // "model"
QT_MOC_LITERAL(11, 149, 25), // "childrenAboutToBeInserted"
QT_MOC_LITERAL(12, 175, 16), // "DataInformation*"
QT_MOC_LITERAL(13, 192, 6), // "sender"
QT_MOC_LITERAL(14, 199, 10), // "startIndex"
QT_MOC_LITERAL(15, 210, 8), // "endIndex"
QT_MOC_LITERAL(16, 219, 16), // "childrenInserted"
QT_MOC_LITERAL(17, 236, 22), // "const DataInformation*"
QT_MOC_LITERAL(18, 259, 24), // "childrenAboutToBeRemoved"
QT_MOC_LITERAL(19, 284, 15), // "childrenRemoved"
QT_MOC_LITERAL(20, 300, 12), // "setByteOrder"
QT_MOC_LITERAL(21, 313, 5), // "order"
QT_MOC_LITERAL(22, 319, 4), // "mark"
QT_MOC_LITERAL(23, 324, 3), // "idx"
QT_MOC_LITERAL(24, 328, 6), // "unmark"
QT_MOC_LITERAL(25, 335, 10), // "updateData"
QT_MOC_LITERAL(26, 346, 30), // "Okteta::ArrayChangeMetricsList"
QT_MOC_LITERAL(27, 377, 4), // "list"
QT_MOC_LITERAL(28, 382, 12), // "addChildItem"
QT_MOC_LITERAL(29, 395, 24), // "TopLevelDataInformation*"
QT_MOC_LITERAL(30, 420, 5), // "child"
QT_MOC_LITERAL(31, 426, 27), // "setSelectedStructuresInView"
QT_MOC_LITERAL(32, 454, 21), // "validateAllStructures"
QT_MOC_LITERAL(33, 476, 18), // "onByteOrderChanged"
QT_MOC_LITERAL(34, 495, 22), // "onCursorPositionChange"
QT_MOC_LITERAL(35, 518, 15), // "Okteta::Address"
QT_MOC_LITERAL(36, 534, 3), // "pos"
QT_MOC_LITERAL(37, 538, 16), // "onContentsChange"
QT_MOC_LITERAL(38, 555, 22) // "onChildItemDataChanged"

    },
    "Kasten::StructTool\0dataChanged\0\0row\0"
    "data\0dataCleared\0byteOrderChanged\0"
    "cursorIndexChanged\0byteArrayModelChanged\0"
    "Okteta::AbstractByteArrayModel*\0model\0"
    "childrenAboutToBeInserted\0DataInformation*\0"
    "sender\0startIndex\0endIndex\0childrenInserted\0"
    "const DataInformation*\0childrenAboutToBeRemoved\0"
    "childrenRemoved\0setByteOrder\0order\0"
    "mark\0idx\0unmark\0updateData\0"
    "Okteta::ArrayChangeMetricsList\0list\0"
    "addChildItem\0TopLevelDataInformation*\0"
    "child\0setSelectedStructuresInView\0"
    "validateAllStructures\0onByteOrderChanged\0"
    "onCursorPositionChange\0Okteta::Address\0"
    "pos\0onContentsChange\0onChildItemDataChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__StructTool[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  114,    2, 0x06 /* Public */,
       5,    0,  119,    2, 0x06 /* Public */,
       6,    0,  120,    2, 0x06 /* Public */,
       7,    0,  121,    2, 0x06 /* Public */,
       8,    1,  122,    2, 0x06 /* Public */,
      11,    3,  125,    2, 0x06 /* Public */,
      16,    3,  132,    2, 0x06 /* Public */,
      18,    3,  139,    2, 0x06 /* Public */,
      19,    3,  146,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      20,    1,  153,    2, 0x0a /* Public */,
      22,    1,  156,    2, 0x0a /* Public */,
      24,    0,  159,    2, 0x0a /* Public */,
      25,    1,  160,    2, 0x0a /* Public */,
      28,    1,  163,    2, 0x0a /* Public */,
      31,    0,  166,    2, 0x0a /* Public */,
      32,    0,  167,    2, 0x0a /* Public */,
      33,    0,  168,    2, 0x09 /* Protected */,
      34,    1,  169,    2, 0x09 /* Protected */,
      37,    1,  172,    2, 0x09 /* Protected */,
      38,    0,  175,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::VoidStar,    3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 12, QMetaType::UInt, QMetaType::UInt,   13,   14,   15,
    QMetaType::Void, 0x80000000 | 17, QMetaType::UInt, QMetaType::UInt,   13,   14,   15,
    QMetaType::Void, 0x80000000 | 12, QMetaType::UInt, QMetaType::UInt,   13,   14,   15,
    QMetaType::Void, 0x80000000 | 17, QMetaType::UInt, QMetaType::UInt,   13,   14,   15,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, QMetaType::QModelIndex,   23,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 26,   27,
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 35,   36,
    QMetaType::Void, 0x80000000 | 26,    2,
    QMetaType::Void,

       0        // eod
};

void Kasten::StructTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StructTool *_t = static_cast<StructTool *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dataChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< void*(*)>(_a[2]))); break;
        case 1: _t->dataCleared(); break;
        case 2: _t->byteOrderChanged(); break;
        case 3: _t->cursorIndexChanged(); break;
        case 4: _t->byteArrayModelChanged((*reinterpret_cast< Okteta::AbstractByteArrayModel*(*)>(_a[1]))); break;
        case 5: _t->childrenAboutToBeInserted((*reinterpret_cast< DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 6: _t->childrenInserted((*reinterpret_cast< const DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 7: _t->childrenAboutToBeRemoved((*reinterpret_cast< DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 8: _t->childrenRemoved((*reinterpret_cast< const DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 9: _t->setByteOrder((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->mark((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 11: _t->unmark(); break;
        case 12: _t->updateData((*reinterpret_cast< const Okteta::ArrayChangeMetricsList(*)>(_a[1]))); break;
        case 13: _t->addChildItem((*reinterpret_cast< TopLevelDataInformation*(*)>(_a[1]))); break;
        case 14: _t->setSelectedStructuresInView(); break;
        case 15: _t->validateAllStructures(); break;
        case 16: _t->onByteOrderChanged(); break;
        case 17: _t->onCursorPositionChange((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        case 18: _t->onContentsChange((*reinterpret_cast< const Okteta::ArrayChangeMetricsList(*)>(_a[1]))); break;
        case 19: _t->onChildItemDataChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TopLevelDataInformation* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (StructTool::*_t)(int , void * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructTool::dataChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (StructTool::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructTool::dataCleared)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (StructTool::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructTool::byteOrderChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (StructTool::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructTool::cursorIndexChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (StructTool::*_t)(Okteta::AbstractByteArrayModel * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructTool::byteArrayModelChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (StructTool::*_t)(DataInformation * , uint , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructTool::childrenAboutToBeInserted)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (StructTool::*_t)(const DataInformation * , uint , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructTool::childrenInserted)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (StructTool::*_t)(DataInformation * , uint , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructTool::childrenAboutToBeRemoved)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (StructTool::*_t)(const DataInformation * , uint , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructTool::childrenRemoved)) {
                *result = 8;
                return;
            }
        }
    }
}

const QMetaObject Kasten::StructTool::staticMetaObject = {
    { &AbstractTool::staticMetaObject, qt_meta_stringdata_Kasten__StructTool.data,
      qt_meta_data_Kasten__StructTool,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::StructTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::StructTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__StructTool.stringdata0))
        return static_cast<void*>(this);
    return AbstractTool::qt_metacast(_clname);
}

int Kasten::StructTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTool::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Kasten::StructTool::dataChanged(int _t1, void * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::StructTool::dataCleared()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Kasten::StructTool::byteOrderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Kasten::StructTool::cursorIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Kasten::StructTool::byteArrayModelChanged(Okteta::AbstractByteArrayModel * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Kasten::StructTool::childrenAboutToBeInserted(DataInformation * _t1, uint _t2, uint _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Kasten::StructTool::childrenInserted(const DataInformation * _t1, uint _t2, uint _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Kasten::StructTool::childrenAboutToBeRemoved(DataInformation * _t1, uint _t2, uint _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Kasten::StructTool::childrenRemoved(const DataInformation * _t1, uint _t2, uint _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
