/****************************************************************************
** Meta object code from reading C++ file 'multiviewareas.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/okteta-17.08.3/libs/kasten/gui/shell/multiviewareas.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multiviewareas.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__MultiViewAreas_t {
    QByteArrayData data[18];
    char stringdata0[267];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__MultiViewAreas_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__MultiViewAreas_t qt_meta_stringdata_Kasten__MultiViewAreas = {
    {
QT_MOC_LITERAL(0, 0, 22), // "Kasten::MultiViewAreas"
QT_MOC_LITERAL(1, 23, 14), // "viewAreasAdded"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 32), // "QList<Kasten::AbstractViewArea*>"
QT_MOC_LITERAL(4, 72, 9), // "viewAreas"
QT_MOC_LITERAL(5, 82, 16), // "viewAreasRemoved"
QT_MOC_LITERAL(6, 99, 20), // "viewAreaFocusChanged"
QT_MOC_LITERAL(7, 120, 25), // "Kasten::AbstractViewArea*"
QT_MOC_LITERAL(8, 146, 8), // "viewArea"
QT_MOC_LITERAL(9, 155, 11), // "dataOffered"
QT_MOC_LITERAL(10, 167, 16), // "const QMimeData*"
QT_MOC_LITERAL(11, 184, 8), // "mimeData"
QT_MOC_LITERAL(12, 193, 5), // "bool&"
QT_MOC_LITERAL(13, 199, 8), // "accepted"
QT_MOC_LITERAL(14, 208, 11), // "dataDropped"
QT_MOC_LITERAL(15, 220, 14), // "onViewsRemoved"
QT_MOC_LITERAL(16, 235, 22), // "onViewAreaFocusChanged"
QT_MOC_LITERAL(17, 258, 8) // "hasFocus"

    },
    "Kasten::MultiViewAreas\0viewAreasAdded\0"
    "\0QList<Kasten::AbstractViewArea*>\0"
    "viewAreas\0viewAreasRemoved\0"
    "viewAreaFocusChanged\0Kasten::AbstractViewArea*\0"
    "viewArea\0dataOffered\0const QMimeData*\0"
    "mimeData\0bool&\0accepted\0dataDropped\0"
    "onViewsRemoved\0onViewAreaFocusChanged\0"
    "hasFocus"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__MultiViewAreas[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       5,    1,   52,    2, 0x06 /* Public */,
       6,    1,   55,    2, 0x06 /* Public */,
       9,    2,   58,    2, 0x06 /* Public */,
      14,    1,   63,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    0,   66,    2, 0x09 /* Protected */,
      16,    1,   67,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 12,   11,   13,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,

       0        // eod
};

void Kasten::MultiViewAreas::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MultiViewAreas *_t = static_cast<MultiViewAreas *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->viewAreasAdded((*reinterpret_cast< const QList<Kasten::AbstractViewArea*>(*)>(_a[1]))); break;
        case 1: _t->viewAreasRemoved((*reinterpret_cast< const QList<Kasten::AbstractViewArea*>(*)>(_a[1]))); break;
        case 2: _t->viewAreaFocusChanged((*reinterpret_cast< Kasten::AbstractViewArea*(*)>(_a[1]))); break;
        case 3: _t->dataOffered((*reinterpret_cast< const QMimeData*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 4: _t->dataDropped((*reinterpret_cast< const QMimeData*(*)>(_a[1]))); break;
        case 5: _t->d_func()->onViewsRemoved(); break;
        case 6: _t->d_func()->onViewAreaFocusChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<Kasten::AbstractViewArea*> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<Kasten::AbstractViewArea*> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Kasten::AbstractViewArea* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (MultiViewAreas::*_t)(const QList<Kasten::AbstractViewArea*> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MultiViewAreas::viewAreasAdded)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MultiViewAreas::*_t)(const QList<Kasten::AbstractViewArea*> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MultiViewAreas::viewAreasRemoved)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (MultiViewAreas::*_t)(Kasten::AbstractViewArea * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MultiViewAreas::viewAreaFocusChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (MultiViewAreas::*_t)(const QMimeData * , bool & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MultiViewAreas::dataOffered)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (MultiViewAreas::*_t)(const QMimeData * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MultiViewAreas::dataDropped)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject Kasten::MultiViewAreas::staticMetaObject = {
    { &AbstractGroupedViews::staticMetaObject, qt_meta_stringdata_Kasten__MultiViewAreas.data,
      qt_meta_data_Kasten__MultiViewAreas,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::MultiViewAreas::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::MultiViewAreas::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__MultiViewAreas.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "If::ToolInlineViewable"))
        return static_cast< If::ToolInlineViewable*>(this);
    if (!strcmp(_clname, "If::ViewAreaSplitable"))
        return static_cast< If::ViewAreaSplitable*>(this);
    if (!strcmp(_clname, "org.kde.kasten.if.toolinlineviewable/1.0"))
        return static_cast< Kasten::If::ToolInlineViewable*>(this);
    if (!strcmp(_clname, "org.kde.kasten.if.viewareasplitable/1.0"))
        return static_cast< Kasten::If::ViewAreaSplitable*>(this);
    return AbstractGroupedViews::qt_metacast(_clname);
}

int Kasten::MultiViewAreas::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractGroupedViews::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Kasten::MultiViewAreas::viewAreasAdded(const QList<Kasten::AbstractViewArea*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::MultiViewAreas::viewAreasRemoved(const QList<Kasten::AbstractViewArea*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kasten::MultiViewAreas::viewAreaFocusChanged(Kasten::AbstractViewArea * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kasten::MultiViewAreas::dataOffered(const QMimeData * _t1, bool & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Kasten::MultiViewAreas::dataDropped(const QMimeData * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
