/****************************************************************************
** Meta object code from reading C++ file 'topleveldatainformation.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/structures/datatypes/topleveldatainformation.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'topleveldatainformation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TopLevelDataInformation_t {
    QByteArrayData data[17];
    char stringdata0[294];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TopLevelDataInformation_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TopLevelDataInformation_t qt_meta_stringdata_TopLevelDataInformation = {
    {
QT_MOC_LITERAL(0, 0, 23), // "TopLevelDataInformation"
QT_MOC_LITERAL(1, 24, 11), // "dataChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 25), // "childrenAboutToBeInserted"
QT_MOC_LITERAL(4, 63, 16), // "DataInformation*"
QT_MOC_LITERAL(5, 80, 6), // "sender"
QT_MOC_LITERAL(6, 87, 10), // "startIndex"
QT_MOC_LITERAL(7, 98, 8), // "endIndex"
QT_MOC_LITERAL(8, 107, 16), // "childrenInserted"
QT_MOC_LITERAL(9, 124, 22), // "const DataInformation*"
QT_MOC_LITERAL(10, 147, 24), // "childrenAboutToBeRemoved"
QT_MOC_LITERAL(11, 172, 15), // "childrenRemoved"
QT_MOC_LITERAL(12, 188, 20), // "resetValidationState"
QT_MOC_LITERAL(13, 209, 17), // "newModelActivated"
QT_MOC_LITERAL(14, 227, 31), // "Okteta::AbstractByteArrayModel*"
QT_MOC_LITERAL(15, 259, 5), // "model"
QT_MOC_LITERAL(16, 265, 28) // "removeByteArrayModelFromList"

    },
    "TopLevelDataInformation\0dataChanged\0"
    "\0childrenAboutToBeInserted\0DataInformation*\0"
    "sender\0startIndex\0endIndex\0childrenInserted\0"
    "const DataInformation*\0childrenAboutToBeRemoved\0"
    "childrenRemoved\0resetValidationState\0"
    "newModelActivated\0Okteta::AbstractByteArrayModel*\0"
    "model\0removeByteArrayModelFromList"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TopLevelDataInformation[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x06 /* Public */,
       3,    3,   55,    2, 0x06 /* Public */,
       8,    3,   62,    2, 0x06 /* Public */,
      10,    3,   69,    2, 0x06 /* Public */,
      11,    3,   76,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,   83,    2, 0x0a /* Public */,
      13,    1,   84,    2, 0x0a /* Public */,
      16,    1,   87,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::UInt, QMetaType::UInt,    5,    6,    7,
    QMetaType::Void, 0x80000000 | 9, QMetaType::UInt, QMetaType::UInt,    5,    6,    7,
    QMetaType::Void, 0x80000000 | 4, QMetaType::UInt, QMetaType::UInt,    5,    6,    7,
    QMetaType::Void, 0x80000000 | 9, QMetaType::UInt, QMetaType::UInt,    5,    6,    7,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, QMetaType::QObjectStar,   15,

       0        // eod
};

void TopLevelDataInformation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TopLevelDataInformation *_t = static_cast<TopLevelDataInformation *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dataChanged(); break;
        case 1: _t->childrenAboutToBeInserted((*reinterpret_cast< DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 2: _t->childrenInserted((*reinterpret_cast< const DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 3: _t->childrenAboutToBeRemoved((*reinterpret_cast< DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 4: _t->childrenRemoved((*reinterpret_cast< const DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 5: _t->resetValidationState(); break;
        case 6: _t->newModelActivated((*reinterpret_cast< Okteta::AbstractByteArrayModel*(*)>(_a[1]))); break;
        case 7: _t->removeByteArrayModelFromList((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (TopLevelDataInformation::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TopLevelDataInformation::dataChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TopLevelDataInformation::*_t)(DataInformation * , uint , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TopLevelDataInformation::childrenAboutToBeInserted)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (TopLevelDataInformation::*_t)(const DataInformation * , uint , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TopLevelDataInformation::childrenInserted)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (TopLevelDataInformation::*_t)(DataInformation * , uint , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TopLevelDataInformation::childrenAboutToBeRemoved)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (TopLevelDataInformation::*_t)(const DataInformation * , uint , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TopLevelDataInformation::childrenRemoved)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject TopLevelDataInformation::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_TopLevelDataInformation.data,
      qt_meta_data_TopLevelDataInformation,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TopLevelDataInformation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TopLevelDataInformation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TopLevelDataInformation.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DataInformationBase"))
        return static_cast< DataInformationBase*>(this);
    return QObject::qt_metacast(_clname);
}

int TopLevelDataInformation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void TopLevelDataInformation::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TopLevelDataInformation::childrenAboutToBeInserted(DataInformation * _t1, uint _t2, uint _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void TopLevelDataInformation::childrenInserted(const DataInformation * _t1, uint _t2, uint _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void TopLevelDataInformation::childrenAboutToBeRemoved(DataInformation * _t1, uint _t2, uint _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void TopLevelDataInformation::childrenRemoved(const DataInformation * _t1, uint _t2, uint _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
