/****************************************************************************
** Meta object code from reading C++ file 'viewprofilesmanagedialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/viewprofiles/viewprofilesmanagedialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewprofilesmanagedialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__ViewProfilesManageDialog_t {
    QByteArrayData data[15];
    char stringdata0[344];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__ViewProfilesManageDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__ViewProfilesManageDialog_t qt_meta_stringdata_Kasten__ViewProfilesManageDialog = {
    {
QT_MOC_LITERAL(0, 0, 32), // "Kasten::ViewProfilesManageDialog"
QT_MOC_LITERAL(1, 33, 29), // "onViewProfileSelectionChanged"
QT_MOC_LITERAL(2, 63, 0), // ""
QT_MOC_LITERAL(3, 64, 24), // "onCreateNewButtonClicked"
QT_MOC_LITERAL(4, 89, 19), // "onEditButtonClicked"
QT_MOC_LITERAL(5, 109, 25), // "onSetDefaultButtonClicked"
QT_MOC_LITERAL(6, 135, 21), // "onDeleteButtonClicked"
QT_MOC_LITERAL(7, 157, 12), // "onModelReset"
QT_MOC_LITERAL(8, 170, 20), // "onViewProfilesLocked"
QT_MOC_LITERAL(9, 191, 39), // "QList<Kasten::ByteArrayViewPr..."
QT_MOC_LITERAL(10, 231, 14), // "viewProfileIds"
QT_MOC_LITERAL(11, 246, 22), // "onViewProfilesUnlocked"
QT_MOC_LITERAL(12, 269, 27), // "onDefaultViewProfileChanged"
QT_MOC_LITERAL(13, 297, 32), // "Kasten::ByteArrayViewProfile::Id"
QT_MOC_LITERAL(14, 330, 13) // "viewProfileId"

    },
    "Kasten::ViewProfilesManageDialog\0"
    "onViewProfileSelectionChanged\0\0"
    "onCreateNewButtonClicked\0onEditButtonClicked\0"
    "onSetDefaultButtonClicked\0"
    "onDeleteButtonClicked\0onModelReset\0"
    "onViewProfilesLocked\0"
    "QList<Kasten::ByteArrayViewProfile::Id>\0"
    "viewProfileIds\0onViewProfilesUnlocked\0"
    "onDefaultViewProfileChanged\0"
    "Kasten::ByteArrayViewProfile::Id\0"
    "viewProfileId"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__ViewProfilesManageDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x09 /* Protected */,
       3,    0,   60,    2, 0x09 /* Protected */,
       4,    0,   61,    2, 0x09 /* Protected */,
       5,    0,   62,    2, 0x09 /* Protected */,
       6,    0,   63,    2, 0x09 /* Protected */,
       7,    0,   64,    2, 0x09 /* Protected */,
       8,    1,   65,    2, 0x09 /* Protected */,
      11,    1,   68,    2, 0x09 /* Protected */,
      12,    1,   71,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 13,   14,

       0        // eod
};

void Kasten::ViewProfilesManageDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ViewProfilesManageDialog *_t = static_cast<ViewProfilesManageDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onViewProfileSelectionChanged(); break;
        case 1: _t->onCreateNewButtonClicked(); break;
        case 2: _t->onEditButtonClicked(); break;
        case 3: _t->onSetDefaultButtonClicked(); break;
        case 4: _t->onDeleteButtonClicked(); break;
        case 5: _t->onModelReset(); break;
        case 6: _t->onViewProfilesLocked((*reinterpret_cast< const QList<Kasten::ByteArrayViewProfile::Id>(*)>(_a[1]))); break;
        case 7: _t->onViewProfilesUnlocked((*reinterpret_cast< const QList<Kasten::ByteArrayViewProfile::Id>(*)>(_a[1]))); break;
        case 8: _t->onDefaultViewProfileChanged((*reinterpret_cast< const Kasten::ByteArrayViewProfile::Id(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::ViewProfilesManageDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Kasten__ViewProfilesManageDialog.data,
      qt_meta_data_Kasten__ViewProfilesManageDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::ViewProfilesManageDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::ViewProfilesManageDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__ViewProfilesManageDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Kasten::ViewProfilesManageDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
