#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'structviewdisplaysettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STRUCTVIEWDISPLAYSETTINGSWIDGET_H
#define UI_STRUCTVIEWDISPLAYSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_StructViewSettings
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout_2;
    QLabel *byteOrderLabel;
    KComboBox *kcfg_ByteOrder;
    QCheckBox *kcfg_ShortTypeNames;
    QCheckBox *kcfg_LocaleAwareDecimalFormatting;
    QLabel *unsigned_label;
    KComboBox *combo_UnsignedDisplayBase;
    QLabel *signed_label;
    KComboBox *combo_SignedDisplayBase;
    QCheckBox *kcfg_LocaleAwareFloatFormatting;
    QLabel *label;
    QSpinBox *kcfg_FloatPrecision;
    QCheckBox *kcfg_ShowCharNumericalValue;
    QLabel *char_label;
    KComboBox *combo_CharDisplayBase;
    QSpinBox *kcfg_CharDisplayBase;
    QSpinBox *kcfg_SignedDisplayBase;
    QSpinBox *kcfg_UnsignedDisplayBase;

    void setupUi(QWidget *StructViewSettings)
    {
        if (StructViewSettings->objectName().isEmpty())
            StructViewSettings->setObjectName(QStringLiteral("StructViewSettings"));
        StructViewSettings->resize(411, 292);
        verticalLayout = new QVBoxLayout(StructViewSettings);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName(QStringLiteral("formLayout_2"));
        formLayout_2->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        byteOrderLabel = new QLabel(StructViewSettings);
        byteOrderLabel->setObjectName(QStringLiteral("byteOrderLabel"));

        formLayout_2->setWidget(0, QFormLayout::LabelRole, byteOrderLabel);

        kcfg_ByteOrder = new KComboBox(StructViewSettings);
        kcfg_ByteOrder->setObjectName(QStringLiteral("kcfg_ByteOrder"));
        kcfg_ByteOrder->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout_2->setWidget(0, QFormLayout::FieldRole, kcfg_ByteOrder);

        kcfg_ShortTypeNames = new QCheckBox(StructViewSettings);
        kcfg_ShortTypeNames->setObjectName(QStringLiteral("kcfg_ShortTypeNames"));

        formLayout_2->setWidget(1, QFormLayout::SpanningRole, kcfg_ShortTypeNames);

        kcfg_LocaleAwareDecimalFormatting = new QCheckBox(StructViewSettings);
        kcfg_LocaleAwareDecimalFormatting->setObjectName(QStringLiteral("kcfg_LocaleAwareDecimalFormatting"));

        formLayout_2->setWidget(2, QFormLayout::SpanningRole, kcfg_LocaleAwareDecimalFormatting);

        unsigned_label = new QLabel(StructViewSettings);
        unsigned_label->setObjectName(QStringLiteral("unsigned_label"));

        formLayout_2->setWidget(3, QFormLayout::LabelRole, unsigned_label);

        combo_UnsignedDisplayBase = new KComboBox(StructViewSettings);
        combo_UnsignedDisplayBase->setObjectName(QStringLiteral("combo_UnsignedDisplayBase"));

        formLayout_2->setWidget(3, QFormLayout::FieldRole, combo_UnsignedDisplayBase);

        signed_label = new QLabel(StructViewSettings);
        signed_label->setObjectName(QStringLiteral("signed_label"));

        formLayout_2->setWidget(4, QFormLayout::LabelRole, signed_label);

        combo_SignedDisplayBase = new KComboBox(StructViewSettings);
        combo_SignedDisplayBase->setObjectName(QStringLiteral("combo_SignedDisplayBase"));

        formLayout_2->setWidget(4, QFormLayout::FieldRole, combo_SignedDisplayBase);

        kcfg_LocaleAwareFloatFormatting = new QCheckBox(StructViewSettings);
        kcfg_LocaleAwareFloatFormatting->setObjectName(QStringLiteral("kcfg_LocaleAwareFloatFormatting"));

        formLayout_2->setWidget(5, QFormLayout::SpanningRole, kcfg_LocaleAwareFloatFormatting);

        label = new QLabel(StructViewSettings);
        label->setObjectName(QStringLiteral("label"));

        formLayout_2->setWidget(6, QFormLayout::LabelRole, label);

        kcfg_FloatPrecision = new QSpinBox(StructViewSettings);
        kcfg_FloatPrecision->setObjectName(QStringLiteral("kcfg_FloatPrecision"));

        formLayout_2->setWidget(6, QFormLayout::FieldRole, kcfg_FloatPrecision);

        kcfg_ShowCharNumericalValue = new QCheckBox(StructViewSettings);
        kcfg_ShowCharNumericalValue->setObjectName(QStringLiteral("kcfg_ShowCharNumericalValue"));

        formLayout_2->setWidget(7, QFormLayout::SpanningRole, kcfg_ShowCharNumericalValue);

        char_label = new QLabel(StructViewSettings);
        char_label->setObjectName(QStringLiteral("char_label"));

        formLayout_2->setWidget(8, QFormLayout::LabelRole, char_label);

        combo_CharDisplayBase = new KComboBox(StructViewSettings);
        combo_CharDisplayBase->setObjectName(QStringLiteral("combo_CharDisplayBase"));

        formLayout_2->setWidget(8, QFormLayout::FieldRole, combo_CharDisplayBase);

        kcfg_CharDisplayBase = new QSpinBox(StructViewSettings);
        kcfg_CharDisplayBase->setObjectName(QStringLiteral("kcfg_CharDisplayBase"));

        formLayout_2->setWidget(9, QFormLayout::LabelRole, kcfg_CharDisplayBase);

        kcfg_SignedDisplayBase = new QSpinBox(StructViewSettings);
        kcfg_SignedDisplayBase->setObjectName(QStringLiteral("kcfg_SignedDisplayBase"));

        formLayout_2->setWidget(9, QFormLayout::FieldRole, kcfg_SignedDisplayBase);

        kcfg_UnsignedDisplayBase = new QSpinBox(StructViewSettings);
        kcfg_UnsignedDisplayBase->setObjectName(QStringLiteral("kcfg_UnsignedDisplayBase"));

        formLayout_2->setWidget(10, QFormLayout::LabelRole, kcfg_UnsignedDisplayBase);


        verticalLayout->addLayout(formLayout_2);

#ifndef UI_QT_NO_SHORTCUT
        byteOrderLabel->setBuddy(kcfg_ByteOrder);
        unsigned_label->setBuddy(combo_UnsignedDisplayBase);
        signed_label->setBuddy(combo_SignedDisplayBase);
        label->setBuddy(kcfg_FloatPrecision);
        char_label->setBuddy(combo_CharDisplayBase);
#endif // QT_NO_SHORTCUT

        retranslateUi(StructViewSettings);
        QObject::connect(kcfg_ShowCharNumericalValue, SIGNAL(toggled(bool)), combo_CharDisplayBase, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(StructViewSettings);
    } // setupUi

    void retranslateUi(QWidget *StructViewSettings)
    {
        byteOrderLabel->setText(tr2i18n("Byte order:", Q_NULLPTR));
        kcfg_ByteOrder->clear();
        kcfg_ByteOrder->insertItems(0, QStringList()
         << tr2i18n("Big endian", Q_NULLPTR)
         << tr2i18n("Little endian", Q_NULLPTR)
        );
        kcfg_ShortTypeNames->setText(tr2i18n("Use short type names", Q_NULLPTR));
        kcfg_LocaleAwareDecimalFormatting->setText(tr2i18n("Use locale-aware integer formatting", Q_NULLPTR));
        unsigned_label->setText(tr2i18n("Unsigned values:", Q_NULLPTR));
        signed_label->setText(tr2i18n("Signed values:", Q_NULLPTR));
        kcfg_LocaleAwareFloatFormatting->setText(tr2i18n("Use locale-aware floating-point formatting", Q_NULLPTR));
        label->setText(tr2i18n("Floating-point precision:", Q_NULLPTR));
        kcfg_ShowCharNumericalValue->setText(tr2i18n("Show numerical value of chars", Q_NULLPTR));
        char_label->setText(tr2i18n("Character value:", Q_NULLPTR));
        Q_UNUSED(StructViewSettings);
    } // retranslateUi

};

namespace Ui {
    class StructViewSettings: public Ui_StructViewSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STRUCTVIEWDISPLAYSETTINGSWIDGET_H

