/****************************************************************************
** Meta object code from reading C++ file 'structtreemodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/structures/structtreemodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'structtreemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__StructTreeModel_t {
    QByteArrayData data[15];
    char stringdata0[226];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__StructTreeModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__StructTreeModel_t qt_meta_stringdata_Kasten__StructTreeModel = {
    {
QT_MOC_LITERAL(0, 0, 23), // "Kasten::StructTreeModel"
QT_MOC_LITERAL(1, 24, 16), // "onToolDataChange"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 3), // "row"
QT_MOC_LITERAL(4, 46, 4), // "data"
QT_MOC_LITERAL(5, 51, 15), // "onToolDataClear"
QT_MOC_LITERAL(6, 67, 26), // "onChildrenAboutToBeRemoved"
QT_MOC_LITERAL(7, 94, 16), // "DataInformation*"
QT_MOC_LITERAL(8, 111, 6), // "sender"
QT_MOC_LITERAL(9, 118, 10), // "startIndex"
QT_MOC_LITERAL(10, 129, 8), // "endIndex"
QT_MOC_LITERAL(11, 138, 27), // "onChildrenAboutToBeInserted"
QT_MOC_LITERAL(12, 166, 17), // "onChildrenRemoved"
QT_MOC_LITERAL(13, 184, 22), // "const DataInformation*"
QT_MOC_LITERAL(14, 207, 18) // "onChildrenInserted"

    },
    "Kasten::StructTreeModel\0onToolDataChange\0"
    "\0row\0data\0onToolDataClear\0"
    "onChildrenAboutToBeRemoved\0DataInformation*\0"
    "sender\0startIndex\0endIndex\0"
    "onChildrenAboutToBeInserted\0"
    "onChildrenRemoved\0const DataInformation*\0"
    "onChildrenInserted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__StructTreeModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x0a /* Public */,
       5,    0,   49,    2, 0x0a /* Public */,
       6,    3,   50,    2, 0x0a /* Public */,
      11,    3,   57,    2, 0x0a /* Public */,
      12,    3,   64,    2, 0x0a /* Public */,
      14,    3,   71,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::VoidStar,    3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, QMetaType::UInt, QMetaType::UInt,    8,    9,   10,
    QMetaType::Void, 0x80000000 | 7, QMetaType::UInt, QMetaType::UInt,    8,    9,   10,
    QMetaType::Void, 0x80000000 | 13, QMetaType::UInt, QMetaType::UInt,    8,    9,   10,
    QMetaType::Void, 0x80000000 | 13, QMetaType::UInt, QMetaType::UInt,    8,    9,   10,

       0        // eod
};

void Kasten::StructTreeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StructTreeModel *_t = static_cast<StructTreeModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onToolDataChange((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< void*(*)>(_a[2]))); break;
        case 1: _t->onToolDataClear(); break;
        case 2: _t->onChildrenAboutToBeRemoved((*reinterpret_cast< DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 3: _t->onChildrenAboutToBeInserted((*reinterpret_cast< DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 4: _t->onChildrenRemoved((*reinterpret_cast< const DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        case 5: _t->onChildrenInserted((*reinterpret_cast< const DataInformation*(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::StructTreeModel::staticMetaObject = {
    { &QAbstractItemModel::staticMetaObject, qt_meta_stringdata_Kasten__StructTreeModel.data,
      qt_meta_data_Kasten__StructTreeModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::StructTreeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::StructTreeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__StructTreeModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int Kasten::StructTreeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
