/****************************************************************************
** Meta object code from reading C++ file 'viewconfigcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/viewconfig/viewconfigcontroller.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewconfigcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__ViewConfigController_t {
    QByteArrayData data[27];
    char stringdata0[486];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__ViewConfigController_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__ViewConfigController_t qt_meta_stringdata_Kasten__ViewConfigController = {
    {
QT_MOC_LITERAL(0, 0, 28), // "Kasten::ViewConfigController"
QT_MOC_LITERAL(1, 29, 14), // "setValueCoding"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 11), // "valueCoding"
QT_MOC_LITERAL(4, 57, 13), // "setCharCoding"
QT_MOC_LITERAL(5, 71, 19), // "setShowsNonprinting"
QT_MOC_LITERAL(6, 91, 2), // "on"
QT_MOC_LITERAL(7, 94, 15), // "setBytesPerLine"
QT_MOC_LITERAL(8, 110, 16), // "setBytesPerGroup"
QT_MOC_LITERAL(9, 127, 14), // "setLayoutStyle"
QT_MOC_LITERAL(10, 142, 11), // "layoutStyle"
QT_MOC_LITERAL(11, 154, 15), // "setOffsetCoding"
QT_MOC_LITERAL(12, 170, 12), // "offsetCoding"
QT_MOC_LITERAL(13, 183, 18), // "toggleOffsetColumn"
QT_MOC_LITERAL(14, 202, 22), // "toggleValueCharColumns"
QT_MOC_LITERAL(15, 225, 14), // "visibleColunms"
QT_MOC_LITERAL(16, 240, 28), // "onOffsetColumnVisibleChanged"
QT_MOC_LITERAL(17, 269, 19), // "offsetColumnVisible"
QT_MOC_LITERAL(18, 289, 21), // "onOffsetCodingChanged"
QT_MOC_LITERAL(19, 311, 25), // "onShowsNonprintingChanged"
QT_MOC_LITERAL(20, 337, 16), // "showsNonprinting"
QT_MOC_LITERAL(21, 354, 20), // "onValueCodingChanged"
QT_MOC_LITERAL(22, 375, 18), // "onCharCodecChanged"
QT_MOC_LITERAL(23, 394, 13), // "charCodecName"
QT_MOC_LITERAL(24, 408, 20), // "onLayoutStyleChanged"
QT_MOC_LITERAL(25, 429, 32), // "onVisibleByteArrayCodingsChanged"
QT_MOC_LITERAL(26, 462, 23) // "visibleByteArrayCodings"

    },
    "Kasten::ViewConfigController\0"
    "setValueCoding\0\0valueCoding\0setCharCoding\0"
    "setShowsNonprinting\0on\0setBytesPerLine\0"
    "setBytesPerGroup\0setLayoutStyle\0"
    "layoutStyle\0setOffsetCoding\0offsetCoding\0"
    "toggleOffsetColumn\0toggleValueCharColumns\0"
    "visibleColunms\0onOffsetColumnVisibleChanged\0"
    "offsetColumnVisible\0onOffsetCodingChanged\0"
    "onShowsNonprintingChanged\0showsNonprinting\0"
    "onValueCodingChanged\0onCharCodecChanged\0"
    "charCodecName\0onLayoutStyleChanged\0"
    "onVisibleByteArrayCodingsChanged\0"
    "visibleByteArrayCodings"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__ViewConfigController[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x08 /* Private */,
       4,    1,   97,    2, 0x08 /* Private */,
       5,    1,  100,    2, 0x08 /* Private */,
       7,    0,  103,    2, 0x08 /* Private */,
       8,    0,  104,    2, 0x08 /* Private */,
       9,    1,  105,    2, 0x08 /* Private */,
      11,    1,  108,    2, 0x08 /* Private */,
      13,    1,  111,    2, 0x08 /* Private */,
      14,    1,  114,    2, 0x08 /* Private */,
      16,    1,  117,    2, 0x08 /* Private */,
      18,    1,  120,    2, 0x08 /* Private */,
      19,    1,  123,    2, 0x08 /* Private */,
      21,    1,  126,    2, 0x08 /* Private */,
      22,    1,  129,    2, 0x08 /* Private */,
      24,    1,  132,    2, 0x08 /* Private */,
      25,    1,  135,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   26,

       0        // eod
};

void Kasten::ViewConfigController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ViewConfigController *_t = static_cast<ViewConfigController *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setValueCoding((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->setCharCoding((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->setShowsNonprinting((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setBytesPerLine(); break;
        case 4: _t->setBytesPerGroup(); break;
        case 5: _t->setLayoutStyle((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->setOffsetCoding((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->toggleOffsetColumn((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->toggleValueCharColumns((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->onOffsetColumnVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->onOffsetCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->onShowsNonprintingChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->onValueCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->onCharCodecChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->onLayoutStyleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->onVisibleByteArrayCodingsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::ViewConfigController::staticMetaObject = {
    { &AbstractXmlGuiController::staticMetaObject, qt_meta_stringdata_Kasten__ViewConfigController.data,
      qt_meta_data_Kasten__ViewConfigController,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::ViewConfigController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::ViewConfigController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__ViewConfigController.stringdata0))
        return static_cast<void*>(this);
    return AbstractXmlGuiController::qt_metacast(_clname);
}

int Kasten::ViewConfigController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractXmlGuiController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
