/****************************************************************************
** Meta object code from reading C++ file 'stringsextractview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/stringsextract/stringsextractview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'stringsextractview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__StringsExtractView_t {
    QByteArrayData data[14];
    char stringdata0[262];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__StringsExtractView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__StringsExtractView_t qt_meta_stringdata_Kasten__StringsExtractView = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Kasten::StringsExtractView"
QT_MOC_LITERAL(1, 27, 21), // "onStringDoubleClicked"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 5), // "index"
QT_MOC_LITERAL(4, 56, 24), // "onStringSelectionChanged"
QT_MOC_LITERAL(5, 81, 19), // "onGotoButtonClicked"
QT_MOC_LITERAL(6, 101, 19), // "onCopyButtonClicked"
QT_MOC_LITERAL(7, 121, 24), // "onStringsUptodateChanged"
QT_MOC_LITERAL(8, 146, 14), // "stringUptodate"
QT_MOC_LITERAL(9, 161, 18), // "onApplyableChanged"
QT_MOC_LITERAL(10, 180, 11), // "isApplyable"
QT_MOC_LITERAL(11, 192, 27), // "onCanHighlightStringChanged"
QT_MOC_LITERAL(12, 220, 12), // "isSelectable"
QT_MOC_LITERAL(13, 233, 28) // "setFixedFontByGlobalSettings"

    },
    "Kasten::StringsExtractView\0"
    "onStringDoubleClicked\0\0index\0"
    "onStringSelectionChanged\0onGotoButtonClicked\0"
    "onCopyButtonClicked\0onStringsUptodateChanged\0"
    "stringUptodate\0onApplyableChanged\0"
    "isApplyable\0onCanHighlightStringChanged\0"
    "isSelectable\0setFixedFontByGlobalSettings"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__StringsExtractView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x08 /* Private */,
       4,    0,   57,    2, 0x08 /* Private */,
       5,    0,   58,    2, 0x08 /* Private */,
       6,    0,   59,    2, 0x08 /* Private */,
       7,    1,   60,    2, 0x08 /* Private */,
       9,    1,   63,    2, 0x08 /* Private */,
      11,    1,   66,    2, 0x08 /* Private */,
      13,    0,   69,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QModelIndex,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,

       0        // eod
};

void Kasten::StringsExtractView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StringsExtractView *_t = static_cast<StringsExtractView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onStringDoubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 1: _t->onStringSelectionChanged(); break;
        case 2: _t->onGotoButtonClicked(); break;
        case 3: _t->onCopyButtonClicked(); break;
        case 4: _t->onStringsUptodateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->onApplyableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->onCanHighlightStringChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->setFixedFontByGlobalSettings(); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::StringsExtractView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Kasten__StringsExtractView.data,
      qt_meta_data_Kasten__StringsExtractView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::StringsExtractView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::StringsExtractView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__StringsExtractView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Kasten::StringsExtractView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
