/****************************************************************************
** Meta object code from reading C++ file 'abstractbytearrayview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/okteta-17.08.3/gui/abstractbytearrayview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractbytearrayview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Okteta__AbstractByteArrayView_t {
    QByteArrayData data[100];
    char stringdata0[1602];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Okteta__AbstractByteArrayView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Okteta__AbstractByteArrayView_t qt_meta_stringdata_Okteta__AbstractByteArrayView = {
    {
QT_MOC_LITERAL(0, 0, 29), // "Okteta::AbstractByteArrayView"
QT_MOC_LITERAL(1, 30, 7), // "clicked"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 15), // "Okteta::Address"
QT_MOC_LITERAL(4, 55, 5), // "index"
QT_MOC_LITERAL(5, 61, 13), // "doubleClicked"
QT_MOC_LITERAL(6, 75, 21), // "cursorPositionChanged"
QT_MOC_LITERAL(7, 97, 20), // "overwriteModeChanged"
QT_MOC_LITERAL(8, 118, 16), // "newOverwriteMode"
QT_MOC_LITERAL(9, 135, 15), // "readOnlyChanged"
QT_MOC_LITERAL(10, 151, 10), // "isReadOnly"
QT_MOC_LITERAL(11, 162, 22), // "hasSelectedDataChanged"
QT_MOC_LITERAL(12, 185, 15), // "hasSelectedData"
QT_MOC_LITERAL(13, 201, 16), // "selectionChanged"
QT_MOC_LITERAL(14, 218, 20), // "Okteta::AddressRange"
QT_MOC_LITERAL(15, 239, 9), // "selection"
QT_MOC_LITERAL(16, 249, 12), // "cutAvailable"
QT_MOC_LITERAL(17, 262, 6), // "Really"
QT_MOC_LITERAL(18, 269, 13), // "copyAvailable"
QT_MOC_LITERAL(19, 283, 16), // "charCodecChanged"
QT_MOC_LITERAL(20, 300, 9), // "codecName"
QT_MOC_LITERAL(21, 310, 18), // "valueCodingChanged"
QT_MOC_LITERAL(22, 329, 11), // "valueCoding"
QT_MOC_LITERAL(23, 341, 12), // "focusChanged"
QT_MOC_LITERAL(24, 354, 8), // "hasFocus"
QT_MOC_LITERAL(25, 363, 26), // "offsetColumnVisibleChanged"
QT_MOC_LITERAL(26, 390, 7), // "visible"
QT_MOC_LITERAL(27, 398, 19), // "offsetCodingChanged"
QT_MOC_LITERAL(28, 418, 12), // "offsetCoding"
QT_MOC_LITERAL(29, 431, 30), // "visibleByteArrayCodingsChanged"
QT_MOC_LITERAL(30, 462, 7), // "columns"
QT_MOC_LITERAL(31, 470, 18), // "layoutStyleChanged"
QT_MOC_LITERAL(32, 489, 11), // "layoutStyle"
QT_MOC_LITERAL(33, 501, 23), // "noOfBytesPerLineChanged"
QT_MOC_LITERAL(34, 525, 16), // "noOfBytesPerLine"
QT_MOC_LITERAL(35, 542, 23), // "showsNonprintingChanged"
QT_MOC_LITERAL(36, 566, 16), // "showsNonprinting"
QT_MOC_LITERAL(37, 583, 21), // "substituteCharChanged"
QT_MOC_LITERAL(38, 605, 14), // "substituteChar"
QT_MOC_LITERAL(39, 620, 20), // "undefinedCharChanged"
QT_MOC_LITERAL(40, 641, 13), // "undefinedChar"
QT_MOC_LITERAL(41, 655, 23), // "noOfGroupedBytesChanged"
QT_MOC_LITERAL(42, 679, 16), // "noOfGroupedBytes"
QT_MOC_LITERAL(43, 696, 16), // "zoomLevelChanged"
QT_MOC_LITERAL(44, 713, 5), // "level"
QT_MOC_LITERAL(45, 719, 15), // "adaptController"
QT_MOC_LITERAL(46, 735, 11), // "blinkCursor"
QT_MOC_LITERAL(47, 747, 25), // "onByteArrayReadOnlyChange"
QT_MOC_LITERAL(48, 773, 19), // "isByteArrayReadOnly"
QT_MOC_LITERAL(49, 793, 17), // "onContentsChanged"
QT_MOC_LITERAL(50, 811, 30), // "Okteta::ArrayChangeMetricsList"
QT_MOC_LITERAL(51, 842, 10), // "changeList"
QT_MOC_LITERAL(52, 853, 17), // "onBookmarksChange"
QT_MOC_LITERAL(53, 871, 23), // "QList<Okteta::Bookmark>"
QT_MOC_LITERAL(54, 895, 9), // "bookmarks"
QT_MOC_LITERAL(55, 905, 24), // "onRevertedToVersionIndex"
QT_MOC_LITERAL(56, 930, 12), // "versionIndex"
QT_MOC_LITERAL(57, 943, 13), // "OverwriteMode"
QT_MOC_LITERAL(58, 957, 13), // "OverwriteOnly"
QT_MOC_LITERAL(59, 971, 8), // "Modified"
QT_MOC_LITERAL(60, 980, 8), // "ReadOnly"
QT_MOC_LITERAL(61, 989, 15), // "TabChangesFocus"
QT_MOC_LITERAL(62, 1005, 11), // "LayoutStyle"
QT_MOC_LITERAL(63, 1017, 16), // "NoOfBytesPerLine"
QT_MOC_LITERAL(64, 1034, 11), // "StartOffset"
QT_MOC_LITERAL(65, 1046, 15), // "FirstLineOffset"
QT_MOC_LITERAL(66, 1062, 19), // "OffsetColumnVisible"
QT_MOC_LITERAL(67, 1082, 12), // "OffsetCoding"
QT_MOC_LITERAL(68, 1095, 14), // "VisibleCodings"
QT_MOC_LITERAL(69, 1110, 11), // "CodingTypes"
QT_MOC_LITERAL(70, 1122, 15), // "ByteTypeColored"
QT_MOC_LITERAL(71, 1138, 6), // "Coding"
QT_MOC_LITERAL(72, 1145, 11), // "ValueCoding"
QT_MOC_LITERAL(73, 1157, 16), // "ByteSpacingWidth"
QT_MOC_LITERAL(74, 1174, 16), // "NoOfGroupedBytes"
QT_MOC_LITERAL(75, 1191, 17), // "GroupSpacingWidth"
QT_MOC_LITERAL(76, 1209, 14), // "BinaryGapWidth"
QT_MOC_LITERAL(77, 1224, 15), // "ShowNonprinting"
QT_MOC_LITERAL(78, 1240, 14), // "SubstituteChar"
QT_MOC_LITERAL(79, 1255, 17), // "HexadecimalOffset"
QT_MOC_LITERAL(80, 1273, 13), // "DecimalOffset"
QT_MOC_LITERAL(81, 1287, 17), // "MaxOffsetCodingId"
QT_MOC_LITERAL(82, 1305, 17), // "HexadecimalCoding"
QT_MOC_LITERAL(83, 1323, 13), // "DecimalCoding"
QT_MOC_LITERAL(84, 1337, 11), // "OctalCoding"
QT_MOC_LITERAL(85, 1349, 12), // "BinaryCoding"
QT_MOC_LITERAL(86, 1362, 11), // "MaxCodingId"
QT_MOC_LITERAL(87, 1374, 10), // "CharCoding"
QT_MOC_LITERAL(88, 1385, 13), // "LocalEncoding"
QT_MOC_LITERAL(89, 1399, 17), // "ISO8859_1Encoding"
QT_MOC_LITERAL(90, 1417, 18), // "EBCDIC1047Encoding"
QT_MOC_LITERAL(91, 1436, 18), // "StartOfOwnEncoding"
QT_MOC_LITERAL(92, 1455, 13), // "MaxEncodingId"
QT_MOC_LITERAL(93, 1469, 16), // "FixedLayoutStyle"
QT_MOC_LITERAL(94, 1486, 29), // "WrapOnlyByteGroupsLayoutStyle"
QT_MOC_LITERAL(95, 1516, 19), // "FullSizeLayoutStyle"
QT_MOC_LITERAL(96, 1536, 14), // "LastUserLayout"
QT_MOC_LITERAL(97, 1551, 15), // "OnlyValueCoding"
QT_MOC_LITERAL(98, 1567, 14), // "OnlyCharCoding"
QT_MOC_LITERAL(99, 1582, 19) // "ValueAndCharCodings"

    },
    "Okteta::AbstractByteArrayView\0clicked\0"
    "\0Okteta::Address\0index\0doubleClicked\0"
    "cursorPositionChanged\0overwriteModeChanged\0"
    "newOverwriteMode\0readOnlyChanged\0"
    "isReadOnly\0hasSelectedDataChanged\0"
    "hasSelectedData\0selectionChanged\0"
    "Okteta::AddressRange\0selection\0"
    "cutAvailable\0Really\0copyAvailable\0"
    "charCodecChanged\0codecName\0"
    "valueCodingChanged\0valueCoding\0"
    "focusChanged\0hasFocus\0offsetColumnVisibleChanged\0"
    "visible\0offsetCodingChanged\0offsetCoding\0"
    "visibleByteArrayCodingsChanged\0columns\0"
    "layoutStyleChanged\0layoutStyle\0"
    "noOfBytesPerLineChanged\0noOfBytesPerLine\0"
    "showsNonprintingChanged\0showsNonprinting\0"
    "substituteCharChanged\0substituteChar\0"
    "undefinedCharChanged\0undefinedChar\0"
    "noOfGroupedBytesChanged\0noOfGroupedBytes\0"
    "zoomLevelChanged\0level\0adaptController\0"
    "blinkCursor\0onByteArrayReadOnlyChange\0"
    "isByteArrayReadOnly\0onContentsChanged\0"
    "Okteta::ArrayChangeMetricsList\0"
    "changeList\0onBookmarksChange\0"
    "QList<Okteta::Bookmark>\0bookmarks\0"
    "onRevertedToVersionIndex\0versionIndex\0"
    "OverwriteMode\0OverwriteOnly\0Modified\0"
    "ReadOnly\0TabChangesFocus\0LayoutStyle\0"
    "NoOfBytesPerLine\0StartOffset\0"
    "FirstLineOffset\0OffsetColumnVisible\0"
    "OffsetCoding\0VisibleCodings\0CodingTypes\0"
    "ByteTypeColored\0Coding\0ValueCoding\0"
    "ByteSpacingWidth\0NoOfGroupedBytes\0"
    "GroupSpacingWidth\0BinaryGapWidth\0"
    "ShowNonprinting\0SubstituteChar\0"
    "HexadecimalOffset\0DecimalOffset\0"
    "MaxOffsetCodingId\0HexadecimalCoding\0"
    "DecimalCoding\0OctalCoding\0BinaryCoding\0"
    "MaxCodingId\0CharCoding\0LocalEncoding\0"
    "ISO8859_1Encoding\0EBCDIC1047Encoding\0"
    "StartOfOwnEncoding\0MaxEncodingId\0"
    "FixedLayoutStyle\0WrapOnlyByteGroupsLayoutStyle\0"
    "FullSizeLayoutStyle\0LastUserLayout\0"
    "OnlyValueCoding\0OnlyCharCoding\0"
    "ValueAndCharCodings"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Okteta__AbstractByteArrayView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
      20,  234, // properties
       5,  294, // enums/sets
       0,    0, // constructors
       0,       // flags
      22,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  154,    2, 0x06 /* Public */,
       5,    1,  157,    2, 0x06 /* Public */,
       6,    1,  160,    2, 0x06 /* Public */,
       7,    1,  163,    2, 0x06 /* Public */,
       9,    1,  166,    2, 0x06 /* Public */,
      11,    1,  169,    2, 0x06 /* Public */,
      13,    1,  172,    2, 0x06 /* Public */,
      16,    1,  175,    2, 0x06 /* Public */,
      18,    1,  178,    2, 0x06 /* Public */,
      19,    1,  181,    2, 0x06 /* Public */,
      21,    1,  184,    2, 0x06 /* Public */,
      23,    1,  187,    2, 0x06 /* Public */,
      25,    1,  190,    2, 0x06 /* Public */,
      27,    1,  193,    2, 0x06 /* Public */,
      29,    1,  196,    2, 0x06 /* Public */,
      31,    1,  199,    2, 0x06 /* Public */,
      33,    1,  202,    2, 0x06 /* Public */,
      35,    1,  205,    2, 0x06 /* Public */,
      37,    1,  208,    2, 0x06 /* Public */,
      39,    1,  211,    2, 0x06 /* Public */,
      41,    1,  214,    2, 0x06 /* Public */,
      43,    1,  217,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      45,    0,  220,    2, 0x08 /* Private */,
      46,    0,  221,    2, 0x08 /* Private */,
      47,    1,  222,    2, 0x08 /* Private */,
      49,    1,  225,    2, 0x08 /* Private */,
      52,    1,  228,    2, 0x08 /* Private */,
      55,    1,  231,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void, QMetaType::Int,   28,
    QMetaType::Void, QMetaType::Int,   30,
    QMetaType::Void, QMetaType::Int,   32,
    QMetaType::Void, QMetaType::Int,   34,
    QMetaType::Void, QMetaType::Bool,   36,
    QMetaType::Void, QMetaType::QChar,   38,
    QMetaType::Void, QMetaType::QChar,   40,
    QMetaType::Void, QMetaType::Int,   42,
    QMetaType::Void, QMetaType::Double,   44,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   48,
    QMetaType::Void, 0x80000000 | 50,   51,
    QMetaType::Void, 0x80000000 | 53,   54,
    QMetaType::Void, QMetaType::Int,   56,

 // properties: name, type, flags
      57, QMetaType::Bool, 0x00095103,
      58, QMetaType::Bool, 0x00095103,
      59, QMetaType::Bool, 0x00094103,
      60, QMetaType::Bool, 0x00095103,
      61, QMetaType::Bool, 0x00095103,
      62, 0x80000000 | 62, 0x0009510b,
      63, QMetaType::Int, 0x00095103,
      64, QMetaType::Int, 0x00095103,
      65, QMetaType::Int, 0x00095103,
      66, QMetaType::Bool, 0x00095003,
      67, 0x80000000 | 67, 0x0009510b,
      68, 0x80000000 | 69, 0x0009510b,
      70, QMetaType::Bool, 0x00095103,
      71, 0x80000000 | 72, 0x0009500b,
      73, QMetaType::Int, 0x00095103,
      74, QMetaType::Int, 0x00095103,
      75, QMetaType::Int, 0x00095103,
      76, QMetaType::Int, 0x00095103,
      77, QMetaType::Bool, 0x00095003,
      78, QMetaType::QChar, 0x00095103,

 // enums: name, flags, count, data
      67, 0x0,    3,  314,
      72, 0x0,    5,  320,
      87, 0x0,    5,  330,
      62, 0x0,    4,  340,
      69, 0x0,    3,  348,

 // enum data: key, value
      79, uint(Okteta::AbstractByteArrayView::HexadecimalOffset),
      80, uint(Okteta::AbstractByteArrayView::DecimalOffset),
      81, uint(Okteta::AbstractByteArrayView::MaxOffsetCodingId),
      82, uint(Okteta::AbstractByteArrayView::HexadecimalCoding),
      83, uint(Okteta::AbstractByteArrayView::DecimalCoding),
      84, uint(Okteta::AbstractByteArrayView::OctalCoding),
      85, uint(Okteta::AbstractByteArrayView::BinaryCoding),
      86, uint(Okteta::AbstractByteArrayView::MaxCodingId),
      88, uint(Okteta::AbstractByteArrayView::LocalEncoding),
      89, uint(Okteta::AbstractByteArrayView::ISO8859_1Encoding),
      90, uint(Okteta::AbstractByteArrayView::EBCDIC1047Encoding),
      91, uint(Okteta::AbstractByteArrayView::StartOfOwnEncoding),
      92, uint(Okteta::AbstractByteArrayView::MaxEncodingId),
      93, uint(Okteta::AbstractByteArrayView::FixedLayoutStyle),
      94, uint(Okteta::AbstractByteArrayView::WrapOnlyByteGroupsLayoutStyle),
      95, uint(Okteta::AbstractByteArrayView::FullSizeLayoutStyle),
      96, uint(Okteta::AbstractByteArrayView::LastUserLayout),
      97, uint(Okteta::AbstractByteArrayView::OnlyValueCoding),
      98, uint(Okteta::AbstractByteArrayView::OnlyCharCoding),
      99, uint(Okteta::AbstractByteArrayView::ValueAndCharCodings),

       0        // eod
};

void Okteta::AbstractByteArrayView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AbstractByteArrayView *_t = static_cast<AbstractByteArrayView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        case 1: _t->doubleClicked((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        case 2: _t->cursorPositionChanged((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        case 3: _t->overwriteModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->readOnlyChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->hasSelectedDataChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->selectionChanged((*reinterpret_cast< const Okteta::AddressRange(*)>(_a[1]))); break;
        case 7: _t->cutAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->copyAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->charCodecChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->valueCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->focusChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->offsetColumnVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->offsetCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->visibleByteArrayCodingsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->layoutStyleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->noOfBytesPerLineChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->showsNonprintingChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->substituteCharChanged((*reinterpret_cast< QChar(*)>(_a[1]))); break;
        case 19: _t->undefinedCharChanged((*reinterpret_cast< QChar(*)>(_a[1]))); break;
        case 20: _t->noOfGroupedBytesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->zoomLevelChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 22: _t->d_func()->adaptController(); break;
        case 23: _t->d_func()->blinkCursor(); break;
        case 24: _t->d_func()->onByteArrayReadOnlyChange((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->d_func()->onContentsChanged((*reinterpret_cast< const Okteta::ArrayChangeMetricsList(*)>(_a[1]))); break;
        case 26: _t->d_func()->onBookmarksChange((*reinterpret_cast< const QList<Okteta::Bookmark>(*)>(_a[1]))); break;
        case 27: _t->d_func()->onRevertedToVersionIndex((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (AbstractByteArrayView::*_t)(Okteta::Address );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(Okteta::Address );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::doubleClicked)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(Okteta::Address );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::cursorPositionChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::overwriteModeChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::readOnlyChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::hasSelectedDataChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(const Okteta::AddressRange & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::selectionChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::cutAvailable)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::copyAvailable)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::charCodecChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::valueCodingChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::focusChanged)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::offsetColumnVisibleChanged)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::offsetCodingChanged)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::visibleByteArrayCodingsChanged)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::layoutStyleChanged)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::noOfBytesPerLineChanged)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::showsNonprintingChanged)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(QChar );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::substituteCharChanged)) {
                *result = 18;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(QChar );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::undefinedCharChanged)) {
                *result = 19;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::noOfGroupedBytesChanged)) {
                *result = 20;
                return;
            }
        }
        {
            typedef void (AbstractByteArrayView::*_t)(double );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractByteArrayView::zoomLevelChanged)) {
                *result = 21;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        AbstractByteArrayView *_t = static_cast<AbstractByteArrayView *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isOverwriteMode(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isOverwriteOnly(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isModified(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isReadOnly(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->tabChangesFocus(); break;
        case 5: *reinterpret_cast< LayoutStyle*>(_v) = _t->layoutStyle(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->noOfBytesPerLine(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->startOffset(); break;
        case 8: *reinterpret_cast< int*>(_v) = _t->firstLineOffset(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->offsetColumnVisible(); break;
        case 10: *reinterpret_cast< OffsetCoding*>(_v) = _t->offsetCoding(); break;
        case 11: *reinterpret_cast< CodingTypes*>(_v) = _t->visibleCodings(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->isByteTypeColored(); break;
        case 13: *reinterpret_cast< ValueCoding*>(_v) = _t->valueCoding(); break;
        case 14: *reinterpret_cast< int*>(_v) = _t->byteSpacingWidth(); break;
        case 15: *reinterpret_cast< int*>(_v) = _t->noOfGroupedBytes(); break;
        case 16: *reinterpret_cast< int*>(_v) = _t->groupSpacingWidth(); break;
        case 17: *reinterpret_cast< int*>(_v) = _t->binaryGapWidth(); break;
        case 18: *reinterpret_cast< bool*>(_v) = _t->showsNonprinting(); break;
        case 19: *reinterpret_cast< QChar*>(_v) = _t->substituteChar(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        AbstractByteArrayView *_t = static_cast<AbstractByteArrayView *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOverwriteMode(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setOverwriteOnly(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setModified(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setReadOnly(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setTabChangesFocus(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setLayoutStyle(*reinterpret_cast< LayoutStyle*>(_v)); break;
        case 6: _t->setNoOfBytesPerLine(*reinterpret_cast< int*>(_v)); break;
        case 7: _t->setStartOffset(*reinterpret_cast< int*>(_v)); break;
        case 8: _t->setFirstLineOffset(*reinterpret_cast< int*>(_v)); break;
        case 9: _t->toggleOffsetColumn(*reinterpret_cast< bool*>(_v)); break;
        case 10: _t->setOffsetCoding(*reinterpret_cast< OffsetCoding*>(_v)); break;
        case 11: _t->setVisibleCodings(*reinterpret_cast< CodingTypes*>(_v)); break;
        case 12: _t->setByteTypeColored(*reinterpret_cast< bool*>(_v)); break;
        case 13: _t->setValueCoding(*reinterpret_cast< ValueCoding*>(_v)); break;
        case 14: _t->setByteSpacingWidth(*reinterpret_cast< int*>(_v)); break;
        case 15: _t->setNoOfGroupedBytes(*reinterpret_cast< int*>(_v)); break;
        case 16: _t->setGroupSpacingWidth(*reinterpret_cast< int*>(_v)); break;
        case 17: _t->setBinaryGapWidth(*reinterpret_cast< int*>(_v)); break;
        case 18: _t->setShowsNonprinting(*reinterpret_cast< bool*>(_v)); break;
        case 19: _t->setSubstituteChar(*reinterpret_cast< QChar*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject Okteta::AbstractByteArrayView::staticMetaObject = {
    { &ColumnsView::staticMetaObject, qt_meta_stringdata_Okteta__AbstractByteArrayView.data,
      qt_meta_data_Okteta__AbstractByteArrayView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Okteta::AbstractByteArrayView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Okteta::AbstractByteArrayView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Okteta__AbstractByteArrayView.stringdata0))
        return static_cast<void*>(this);
    return ColumnsView::qt_metacast(_clname);
}

int Okteta::AbstractByteArrayView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ColumnsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 28;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 20;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 20;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 20;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 20;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 20;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Okteta::AbstractByteArrayView::clicked(Okteta::Address _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Okteta::AbstractByteArrayView::doubleClicked(Okteta::Address _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Okteta::AbstractByteArrayView::cursorPositionChanged(Okteta::Address _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Okteta::AbstractByteArrayView::overwriteModeChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Okteta::AbstractByteArrayView::readOnlyChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Okteta::AbstractByteArrayView::hasSelectedDataChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Okteta::AbstractByteArrayView::selectionChanged(const Okteta::AddressRange & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Okteta::AbstractByteArrayView::cutAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Okteta::AbstractByteArrayView::copyAvailable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Okteta::AbstractByteArrayView::charCodecChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Okteta::AbstractByteArrayView::valueCodingChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Okteta::AbstractByteArrayView::focusChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Okteta::AbstractByteArrayView::offsetColumnVisibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Okteta::AbstractByteArrayView::offsetCodingChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Okteta::AbstractByteArrayView::visibleByteArrayCodingsChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Okteta::AbstractByteArrayView::layoutStyleChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Okteta::AbstractByteArrayView::noOfBytesPerLineChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void Okteta::AbstractByteArrayView::showsNonprintingChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void Okteta::AbstractByteArrayView::substituteCharChanged(QChar _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void Okteta::AbstractByteArrayView::undefinedCharChanged(QChar _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void Okteta::AbstractByteArrayView::noOfGroupedBytesChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void Okteta::AbstractByteArrayView::zoomLevelChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
