/****************************************************************************
** Meta object code from reading C++ file 'tabbedviews.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/okteta-17.08.3/libs/kasten/gui/shell/tabbedviews.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabbedviews.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__TabbedViews_t {
    QByteArrayData data[21];
    char stringdata0[267];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__TabbedViews_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__TabbedViews_t qt_meta_stringdata_Kasten__TabbedViews = {
    {
QT_MOC_LITERAL(0, 0, 19), // "Kasten::TabbedViews"
QT_MOC_LITERAL(1, 20, 11), // "dataOffered"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 16), // "const QMimeData*"
QT_MOC_LITERAL(4, 50, 8), // "mimeData"
QT_MOC_LITERAL(5, 59, 5), // "bool&"
QT_MOC_LITERAL(6, 65, 8), // "accepted"
QT_MOC_LITERAL(7, 74, 11), // "dataDropped"
QT_MOC_LITERAL(8, 86, 16), // "onCurrentChanged"
QT_MOC_LITERAL(9, 103, 5), // "index"
QT_MOC_LITERAL(10, 109, 17), // "onTabCloseRequest"
QT_MOC_LITERAL(11, 127, 14), // "onTitleChanged"
QT_MOC_LITERAL(12, 142, 5), // "title"
QT_MOC_LITERAL(13, 148, 18), // "onViewFocusChanged"
QT_MOC_LITERAL(14, 167, 12), // "focusChanged"
QT_MOC_LITERAL(15, 180, 18), // "onMouseMiddleClick"
QT_MOC_LITERAL(16, 199, 15), // "onDragMoveEvent"
QT_MOC_LITERAL(17, 215, 21), // "const QDragMoveEvent*"
QT_MOC_LITERAL(18, 237, 11), // "onDropEvent"
QT_MOC_LITERAL(19, 249, 11), // "QDropEvent*"
QT_MOC_LITERAL(20, 261, 5) // "event"

    },
    "Kasten::TabbedViews\0dataOffered\0\0"
    "const QMimeData*\0mimeData\0bool&\0"
    "accepted\0dataDropped\0onCurrentChanged\0"
    "index\0onTabCloseRequest\0onTitleChanged\0"
    "title\0onViewFocusChanged\0focusChanged\0"
    "onMouseMiddleClick\0onDragMoveEvent\0"
    "const QDragMoveEvent*\0onDropEvent\0"
    "QDropEvent*\0event"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__TabbedViews[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   59,    2, 0x06 /* Public */,
       7,    1,   64,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   67,    2, 0x09 /* Protected */,
      10,    1,   70,    2, 0x09 /* Protected */,
      11,    1,   73,    2, 0x09 /* Protected */,
      13,    1,   76,    2, 0x09 /* Protected */,
      15,    0,   79,    2, 0x09 /* Protected */,
      16,    2,   80,    2, 0x09 /* Protected */,
      18,    1,   85,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17, 0x80000000 | 5,    2,    2,
    QMetaType::Void, 0x80000000 | 19,   20,

       0        // eod
};

void Kasten::TabbedViews::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TabbedViews *_t = static_cast<TabbedViews *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dataOffered((*reinterpret_cast< const QMimeData*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->dataDropped((*reinterpret_cast< const QMimeData*(*)>(_a[1]))); break;
        case 2: _t->d_func()->onCurrentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->d_func()->onTabCloseRequest((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->d_func()->onTitleChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->d_func()->onViewFocusChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->d_func()->onMouseMiddleClick(); break;
        case 7: _t->d_func()->onDragMoveEvent((*reinterpret_cast< const QDragMoveEvent*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 8: _t->d_func()->onDropEvent((*reinterpret_cast< QDropEvent*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (TabbedViews::*_t)(const QMimeData * , bool & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabbedViews::dataOffered)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TabbedViews::*_t)(const QMimeData * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabbedViews::dataDropped)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Kasten::TabbedViews::staticMetaObject = {
    { &AbstractGroupedViews::staticMetaObject, qt_meta_stringdata_Kasten__TabbedViews.data,
      qt_meta_data_Kasten__TabbedViews,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::TabbedViews::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::TabbedViews::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__TabbedViews.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "If::ToolInlineViewable"))
        return static_cast< If::ToolInlineViewable*>(this);
    if (!strcmp(_clname, "org.kde.kasten.if.toolinlineviewable/1.0"))
        return static_cast< Kasten::If::ToolInlineViewable*>(this);
    return AbstractGroupedViews::qt_metacast(_clname);
}

int Kasten::TabbedViews::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractGroupedViews::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Kasten::TabbedViews::dataOffered(const QMimeData * _t1, bool & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::TabbedViews::dataDropped(const QMimeData * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
