/****************************************************************************
** Meta object code from reading C++ file 'charsetconversiontool.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/charsetconversion/charsetconversiontool.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'charsetconversiontool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__CharsetConversionTool_t {
    QByteArrayData data[19];
    char stringdata0[327];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__CharsetConversionTool_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__CharsetConversionTool_t qt_meta_stringdata_Kasten__CharsetConversionTool = {
    {
QT_MOC_LITERAL(0, 0, 29), // "Kasten::CharsetConversionTool"
QT_MOC_LITERAL(1, 30, 18), // "isApplyableChanged"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 11), // "isApplyable"
QT_MOC_LITERAL(4, 62, 14), // "conversionDone"
QT_MOC_LITERAL(5, 77, 7), // "success"
QT_MOC_LITERAL(6, 85, 19), // "convertedBytesCount"
QT_MOC_LITERAL(7, 105, 22), // "QMap<Okteta::Byte,int>"
QT_MOC_LITERAL(8, 128, 18), // "failedPerByteCount"
QT_MOC_LITERAL(9, 147, 22), // "setConversionDirection"
QT_MOC_LITERAL(10, 170, 19), // "conversionDirection"
QT_MOC_LITERAL(11, 190, 21), // "setOtherCharCodecName"
QT_MOC_LITERAL(12, 212, 9), // "codecName"
QT_MOC_LITERAL(13, 222, 27), // "setSubstitutingMissingChars"
QT_MOC_LITERAL(14, 250, 26), // "isSubstitutingMissingChars"
QT_MOC_LITERAL(15, 277, 17), // "setSubstituteByte"
QT_MOC_LITERAL(16, 295, 4), // "byte"
QT_MOC_LITERAL(17, 300, 12), // "convertChars"
QT_MOC_LITERAL(18, 313, 13) // "onViewChanged"

    },
    "Kasten::CharsetConversionTool\0"
    "isApplyableChanged\0\0isApplyable\0"
    "conversionDone\0success\0convertedBytesCount\0"
    "QMap<Okteta::Byte,int>\0failedPerByteCount\0"
    "setConversionDirection\0conversionDirection\0"
    "setOtherCharCodecName\0codecName\0"
    "setSubstitutingMissingChars\0"
    "isSubstitutingMissingChars\0setSubstituteByte\0"
    "byte\0convertChars\0onViewChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__CharsetConversionTool[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    3,   57,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   64,    2, 0x0a /* Public */,
      11,    1,   67,    2, 0x0a /* Public */,
      13,    1,   70,    2, 0x0a /* Public */,
      15,    1,   73,    2, 0x0a /* Public */,
      17,    0,   76,    2, 0x0a /* Public */,
      18,    0,   77,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 7,    5,    6,    8,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, QMetaType::Int,   16,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Kasten::CharsetConversionTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CharsetConversionTool *_t = static_cast<CharsetConversionTool *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->isApplyableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->conversionDone((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QMap<Okteta::Byte,int>(*)>(_a[3]))); break;
        case 2: _t->setConversionDirection((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->setOtherCharCodecName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->setSubstitutingMissingChars((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->setSubstituteByte((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->convertChars(); break;
        case 7: _t->onViewChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (CharsetConversionTool::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CharsetConversionTool::isApplyableChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (CharsetConversionTool::*_t)(bool , int , const QMap<Okteta::Byte,int> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&CharsetConversionTool::conversionDone)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Kasten::CharsetConversionTool::staticMetaObject = {
    { &AbstractTool::staticMetaObject, qt_meta_stringdata_Kasten__CharsetConversionTool.data,
      qt_meta_data_Kasten__CharsetConversionTool,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::CharsetConversionTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::CharsetConversionTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__CharsetConversionTool.stringdata0))
        return static_cast<void*>(this);
    return AbstractTool::qt_metacast(_clname);
}

int Kasten::CharsetConversionTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTool::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Kasten::CharsetConversionTool::isApplyableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::CharsetConversionTool::conversionDone(bool _t1, int _t2, const QMap<Okteta::Byte,int> & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
