/****************************************************************************
** Meta object code from reading C++ file 'structuresmanagerview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/structures/settings/structuresmanagerview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'structuresmanagerview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_StructuresManagerView_t {
    QByteArrayData data[12];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_StructuresManagerView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_StructuresManagerView_t qt_meta_stringdata_StructuresManagerView = {
    {
QT_MOC_LITERAL(0, 0, 21), // "StructuresManagerView"
QT_MOC_LITERAL(1, 22, 22), // "selectedPluginsChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 7), // "changed"
QT_MOC_LITERAL(4, 54, 9), // "newValues"
QT_MOC_LITERAL(5, 64, 25), // "onGetNewStructuresClicked"
QT_MOC_LITERAL(6, 90, 17), // "KNS3::Entry::List"
QT_MOC_LITERAL(7, 108, 14), // "changedEntries"
QT_MOC_LITERAL(8, 123, 22), // "onPluginSelectorChange"
QT_MOC_LITERAL(9, 146, 6), // "change"
QT_MOC_LITERAL(10, 153, 17), // "advancedSelection"
QT_MOC_LITERAL(11, 171, 6) // "values"

    },
    "StructuresManagerView\0selectedPluginsChanged\0"
    "\0changed\0newValues\0onGetNewStructuresClicked\0"
    "KNS3::Entry::List\0changedEntries\0"
    "onPluginSelectorChange\0change\0"
    "advancedSelection\0values"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_StructuresManagerView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       1,   50, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    1,   40,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   43,    2, 0x09 /* Protected */,
       8,    1,   46,    2, 0x09 /* Protected */,
      10,    0,   49,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QStringList,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,

 // properties: name, type, flags
      11, QMetaType::QStringList, 0x00195001,

       0        // eod
};

void StructuresManagerView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        StructuresManagerView *_t = static_cast<StructuresManagerView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->selectedPluginsChanged(); break;
        case 1: _t->changed((*reinterpret_cast< QStringList(*)>(_a[1]))); break;
        case 2: _t->onGetNewStructuresClicked((*reinterpret_cast< const KNS3::Entry::List(*)>(_a[1]))); break;
        case 3: _t->onPluginSelectorChange((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->advancedSelection(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (StructuresManagerView::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructuresManagerView::selectedPluginsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (StructuresManagerView::*_t)(QStringList );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&StructuresManagerView::changed)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        StructuresManagerView *_t = static_cast<StructuresManagerView *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QStringList*>(_v) = _t->values(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject StructuresManagerView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_StructuresManagerView.data,
      qt_meta_data_StructuresManagerView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *StructuresManagerView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StructuresManagerView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_StructuresManagerView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int StructuresManagerView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void StructuresManagerView::selectedPluginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void StructuresManagerView::changed(QStringList _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
