/****************************************************************************
** Meta object code from reading C++ file 'abstractgroupedviews.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/okteta-17.08.3/libs/kasten/gui/shell/abstractgroupedviews.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractgroupedviews.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__AbstractGroupedViews_t {
    QByteArrayData data[14];
    char stringdata0[185];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__AbstractGroupedViews_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__AbstractGroupedViews_t qt_meta_stringdata_Kasten__AbstractGroupedViews = {
    {
QT_MOC_LITERAL(0, 0, 28), // "Kasten::AbstractGroupedViews"
QT_MOC_LITERAL(1, 29, 5), // "added"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 28), // "QList<Kasten::AbstractView*>"
QT_MOC_LITERAL(4, 65, 5), // "views"
QT_MOC_LITERAL(5, 71, 8), // "removing"
QT_MOC_LITERAL(6, 80, 12), // "closeRequest"
QT_MOC_LITERAL(7, 93, 16), // "viewFocusChanged"
QT_MOC_LITERAL(8, 110, 21), // "Kasten::AbstractView*"
QT_MOC_LITERAL(9, 132, 4), // "view"
QT_MOC_LITERAL(10, 137, 8), // "addViews"
QT_MOC_LITERAL(11, 146, 11), // "removeViews"
QT_MOC_LITERAL(12, 158, 12), // "setViewFocus"
QT_MOC_LITERAL(13, 171, 13) // "AbstractView*"

    },
    "Kasten::AbstractGroupedViews\0added\0\0"
    "QList<Kasten::AbstractView*>\0views\0"
    "removing\0closeRequest\0viewFocusChanged\0"
    "Kasten::AbstractView*\0view\0addViews\0"
    "removeViews\0setViewFocus\0AbstractView*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__AbstractGroupedViews[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       5,    1,   52,    2, 0x06 /* Public */,
       6,    1,   55,    2, 0x06 /* Public */,
       7,    1,   58,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,   61,    2, 0x0a /* Public */,
      11,    1,   64,    2, 0x0a /* Public */,
      12,    1,   67,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 8,    9,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 13,    9,

       0        // eod
};

void Kasten::AbstractGroupedViews::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AbstractGroupedViews *_t = static_cast<AbstractGroupedViews *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->added((*reinterpret_cast< const QList<Kasten::AbstractView*>(*)>(_a[1]))); break;
        case 1: _t->removing((*reinterpret_cast< const QList<Kasten::AbstractView*>(*)>(_a[1]))); break;
        case 2: _t->closeRequest((*reinterpret_cast< const QList<Kasten::AbstractView*>(*)>(_a[1]))); break;
        case 3: _t->viewFocusChanged((*reinterpret_cast< Kasten::AbstractView*(*)>(_a[1]))); break;
        case 4: _t->addViews((*reinterpret_cast< const QList<Kasten::AbstractView*>(*)>(_a[1]))); break;
        case 5: _t->removeViews((*reinterpret_cast< const QList<Kasten::AbstractView*>(*)>(_a[1]))); break;
        case 6: _t->setViewFocus((*reinterpret_cast< AbstractView*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (AbstractGroupedViews::*_t)(const QList<Kasten::AbstractView*> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractGroupedViews::added)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (AbstractGroupedViews::*_t)(const QList<Kasten::AbstractView*> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractGroupedViews::removing)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (AbstractGroupedViews::*_t)(const QList<Kasten::AbstractView*> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractGroupedViews::closeRequest)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (AbstractGroupedViews::*_t)(Kasten::AbstractView * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractGroupedViews::viewFocusChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject Kasten::AbstractGroupedViews::staticMetaObject = {
    { &AbstractViewArea::staticMetaObject, qt_meta_stringdata_Kasten__AbstractGroupedViews.data,
      qt_meta_data_Kasten__AbstractGroupedViews,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::AbstractGroupedViews::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::AbstractGroupedViews::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__AbstractGroupedViews.stringdata0))
        return static_cast<void*>(this);
    return AbstractViewArea::qt_metacast(_clname);
}

int Kasten::AbstractGroupedViews::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractViewArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Kasten::AbstractGroupedViews::added(const QList<Kasten::AbstractView*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::AbstractGroupedViews::removing(const QList<Kasten::AbstractView*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kasten::AbstractGroupedViews::closeRequest(const QList<Kasten::AbstractView*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kasten::AbstractGroupedViews::viewFocusChanged(Kasten::AbstractView * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
