/****************************************************************************
** Meta object code from reading C++ file 'documentlistmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/okteta-17.08.3/libs/kasten/controllers/documentsystem/documentsbrowser/documentlistmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documentlistmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__DocumentListModel_t {
    QByteArrayData data[13];
    char stringdata0[257];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__DocumentListModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__DocumentListModel_t qt_meta_stringdata_Kasten__DocumentListModel = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Kasten::DocumentListModel"
QT_MOC_LITERAL(1, 26, 16), // "onDocumentsAdded"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 32), // "QList<Kasten::AbstractDocument*>"
QT_MOC_LITERAL(4, 77, 9), // "documents"
QT_MOC_LITERAL(5, 87, 18), // "onDocumentsClosing"
QT_MOC_LITERAL(6, 106, 25), // "onFocussedDocumentChanged"
QT_MOC_LITERAL(7, 132, 25), // "Kasten::AbstractDocument*"
QT_MOC_LITERAL(8, 158, 8), // "document"
QT_MOC_LITERAL(9, 167, 19), // "onSyncStatesChanged"
QT_MOC_LITERAL(10, 187, 21), // "onSynchronizerChanged"
QT_MOC_LITERAL(11, 209, 34), // "Kasten::AbstractModelSynchron..."
QT_MOC_LITERAL(12, 244, 12) // "synchronizer"

    },
    "Kasten::DocumentListModel\0onDocumentsAdded\0"
    "\0QList<Kasten::AbstractDocument*>\0"
    "documents\0onDocumentsClosing\0"
    "onFocussedDocumentChanged\0"
    "Kasten::AbstractDocument*\0document\0"
    "onSyncStatesChanged\0onSynchronizerChanged\0"
    "Kasten::AbstractModelSynchronizer*\0"
    "synchronizer"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__DocumentListModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x08 /* Private */,
       5,    1,   42,    2, 0x08 /* Private */,
       6,    1,   45,    2, 0x08 /* Private */,
       9,    0,   48,    2, 0x08 /* Private */,
      10,    1,   49,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,   12,

       0        // eod
};

void Kasten::DocumentListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DocumentListModel *_t = static_cast<DocumentListModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onDocumentsAdded((*reinterpret_cast< const QList<Kasten::AbstractDocument*>(*)>(_a[1]))); break;
        case 1: _t->onDocumentsClosing((*reinterpret_cast< const QList<Kasten::AbstractDocument*>(*)>(_a[1]))); break;
        case 2: _t->onFocussedDocumentChanged((*reinterpret_cast< Kasten::AbstractDocument*(*)>(_a[1]))); break;
        case 3: _t->onSyncStatesChanged(); break;
        case 4: _t->onSynchronizerChanged((*reinterpret_cast< Kasten::AbstractModelSynchronizer*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::DocumentListModel::staticMetaObject = {
    { &QAbstractTableModel::staticMetaObject, qt_meta_stringdata_Kasten__DocumentListModel.data,
      qt_meta_data_Kasten__DocumentListModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::DocumentListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::DocumentListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__DocumentListModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractTableModel::qt_metacast(_clname);
}

int Kasten::DocumentListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
