/****************************************************************************
** Meta object code from reading C++ file 'viewstatuscontroller.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/viewstatus/viewstatuscontroller.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewstatuscontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__ViewStatusController_t {
    QByteArrayData data[19];
    char stringdata0[320];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__ViewStatusController_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__ViewStatusController_t qt_meta_stringdata_Kasten__ViewStatusController = {
    {
QT_MOC_LITERAL(0, 0, 28), // "Kasten::ViewStatusController"
QT_MOC_LITERAL(1, 29, 16), // "setOverwriteMode"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 9), // "overwrite"
QT_MOC_LITERAL(4, 57, 14), // "setValueCoding"
QT_MOC_LITERAL(5, 72, 11), // "valueCoding"
QT_MOC_LITERAL(6, 84, 13), // "setCharCoding"
QT_MOC_LITERAL(7, 98, 10), // "charCoding"
QT_MOC_LITERAL(8, 109, 23), // "onCursorPositionChanged"
QT_MOC_LITERAL(9, 133, 15), // "Okteta::Address"
QT_MOC_LITERAL(10, 149, 6), // "offset"
QT_MOC_LITERAL(11, 156, 21), // "onSelectedDataChanged"
QT_MOC_LITERAL(12, 178, 37), // "const Kasten::AbstractModelSe..."
QT_MOC_LITERAL(13, 216, 14), // "modelSelection"
QT_MOC_LITERAL(14, 231, 21), // "onOffsetCodingChanged"
QT_MOC_LITERAL(15, 253, 12), // "offsetCoding"
QT_MOC_LITERAL(16, 266, 20), // "onValueCodingChanged"
QT_MOC_LITERAL(17, 287, 18), // "onCharCodecChanged"
QT_MOC_LITERAL(18, 306, 13) // "charCodecName"

    },
    "Kasten::ViewStatusController\0"
    "setOverwriteMode\0\0overwrite\0setValueCoding\0"
    "valueCoding\0setCharCoding\0charCoding\0"
    "onCursorPositionChanged\0Okteta::Address\0"
    "offset\0onSelectedDataChanged\0"
    "const Kasten::AbstractModelSelection*\0"
    "modelSelection\0onOffsetCodingChanged\0"
    "offsetCoding\0onValueCodingChanged\0"
    "onCharCodecChanged\0charCodecName"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__ViewStatusController[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x08 /* Private */,
       4,    1,   57,    2, 0x08 /* Private */,
       6,    1,   60,    2, 0x08 /* Private */,
       8,    1,   63,    2, 0x08 /* Private */,
      11,    1,   66,    2, 0x08 /* Private */,
      14,    1,   69,    2, 0x08 /* Private */,
      16,    1,   72,    2, 0x08 /* Private */,
      17,    1,   75,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,   18,

       0        // eod
};

void Kasten::ViewStatusController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ViewStatusController *_t = static_cast<ViewStatusController *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->setOverwriteMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->setValueCoding((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->setCharCoding((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->onCursorPositionChanged((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        case 4: _t->onSelectedDataChanged((*reinterpret_cast< const Kasten::AbstractModelSelection*(*)>(_a[1]))); break;
        case 5: _t->onOffsetCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->onValueCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->onCharCodecChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::ViewStatusController::staticMetaObject = {
    { &AbstractXmlGuiController::staticMetaObject, qt_meta_stringdata_Kasten__ViewStatusController.data,
      qt_meta_data_Kasten__ViewStatusController,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::ViewStatusController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::ViewStatusController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__ViewStatusController.stringdata0))
        return static_cast<void*>(this);
    return AbstractXmlGuiController::qt_metacast(_clname);
}

int Kasten::ViewStatusController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractXmlGuiController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
