/****************************************************************************
** Meta object code from reading C++ file 'bookmarkstool.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/bookmarks/bookmarkstool.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bookmarkstool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__BookmarksTool_t {
    QByteArrayData data[19];
    char stringdata0[307];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__BookmarksTool_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__BookmarksTool_t qt_meta_stringdata_Kasten__BookmarksTool = {
    {
QT_MOC_LITERAL(0, 0, 21), // "Kasten::BookmarksTool"
QT_MOC_LITERAL(1, 22, 19), // "hasBookmarksChanged"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 12), // "hasBookmarks"
QT_MOC_LITERAL(4, 56, 14), // "bookmarksAdded"
QT_MOC_LITERAL(5, 71, 23), // "QList<Okteta::Bookmark>"
QT_MOC_LITERAL(6, 95, 9), // "bookmarks"
QT_MOC_LITERAL(7, 105, 16), // "bookmarksRemoved"
QT_MOC_LITERAL(8, 122, 17), // "bookmarksModified"
QT_MOC_LITERAL(9, 140, 10), // "QList<int>"
QT_MOC_LITERAL(10, 151, 7), // "indizes"
QT_MOC_LITERAL(11, 159, 24), // "canCreateBookmarkChanged"
QT_MOC_LITERAL(12, 184, 17), // "canCreateBookmark"
QT_MOC_LITERAL(13, 202, 19), // "offsetCodingChanged"
QT_MOC_LITERAL(14, 222, 12), // "offsetCoding"
QT_MOC_LITERAL(15, 235, 23), // "onCursorPositionChanged"
QT_MOC_LITERAL(16, 259, 15), // "Okteta::Address"
QT_MOC_LITERAL(17, 275, 11), // "newPosition"
QT_MOC_LITERAL(18, 287, 19) // "onBookmarksModified"

    },
    "Kasten::BookmarksTool\0hasBookmarksChanged\0"
    "\0hasBookmarks\0bookmarksAdded\0"
    "QList<Okteta::Bookmark>\0bookmarks\0"
    "bookmarksRemoved\0bookmarksModified\0"
    "QList<int>\0indizes\0canCreateBookmarkChanged\0"
    "canCreateBookmark\0offsetCodingChanged\0"
    "offsetCoding\0onCursorPositionChanged\0"
    "Okteta::Address\0newPosition\0"
    "onBookmarksModified"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__BookmarksTool[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    1,   57,    2, 0x06 /* Public */,
       7,    1,   60,    2, 0x06 /* Public */,
       8,    1,   63,    2, 0x06 /* Public */,
      11,    1,   66,    2, 0x06 /* Public */,
      13,    1,   69,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      15,    1,   72,    2, 0x08 /* Private */,
      18,    0,   75,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Int,   14,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void,

       0        // eod
};

void Kasten::BookmarksTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        BookmarksTool *_t = static_cast<BookmarksTool *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->hasBookmarksChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->bookmarksAdded((*reinterpret_cast< const QList<Okteta::Bookmark>(*)>(_a[1]))); break;
        case 2: _t->bookmarksRemoved((*reinterpret_cast< const QList<Okteta::Bookmark>(*)>(_a[1]))); break;
        case 3: _t->bookmarksModified((*reinterpret_cast< const QList<int>(*)>(_a[1]))); break;
        case 4: _t->canCreateBookmarkChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->offsetCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->onCursorPositionChanged((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        case 7: _t->onBookmarksModified(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (BookmarksTool::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&BookmarksTool::hasBookmarksChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (BookmarksTool::*_t)(const QList<Okteta::Bookmark> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&BookmarksTool::bookmarksAdded)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (BookmarksTool::*_t)(const QList<Okteta::Bookmark> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&BookmarksTool::bookmarksRemoved)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (BookmarksTool::*_t)(const QList<int> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&BookmarksTool::bookmarksModified)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (BookmarksTool::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&BookmarksTool::canCreateBookmarkChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (BookmarksTool::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&BookmarksTool::offsetCodingChanged)) {
                *result = 5;
                return;
            }
        }
    }
}

const QMetaObject Kasten::BookmarksTool::staticMetaObject = {
    { &AbstractTool::staticMetaObject, qt_meta_stringdata_Kasten__BookmarksTool.data,
      qt_meta_data_Kasten__BookmarksTool,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::BookmarksTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::BookmarksTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__BookmarksTool.stringdata0))
        return static_cast<void*>(this);
    return AbstractTool::qt_metacast(_clname);
}

int Kasten::BookmarksTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTool::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Kasten::BookmarksTool::hasBookmarksChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::BookmarksTool::bookmarksAdded(const QList<Okteta::Bookmark> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kasten::BookmarksTool::bookmarksRemoved(const QList<Okteta::Bookmark> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kasten::BookmarksTool::bookmarksModified(const QList<int> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Kasten::BookmarksTool::canCreateBookmarkChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Kasten::BookmarksTool::offsetCodingChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
