/****************************************************************************
** Meta object code from reading C++ file 'bytearraydocument.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/core/document/bytearraydocument.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bytearraydocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__ByteArrayDocument_t {
    QByteArrayData data[17];
    char stringdata0[287];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__ByteArrayDocument_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__ByteArrayDocument_t qt_meta_stringdata_Kasten__ByteArrayDocument = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Kasten::ByteArrayDocument"
QT_MOC_LITERAL(1, 26, 22), // "revertedToVersionIndex"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 12), // "versionIndex"
QT_MOC_LITERAL(4, 63, 22), // "headVersionDataChanged"
QT_MOC_LITERAL(5, 86, 27), // "Kasten::DocumentVersionData"
QT_MOC_LITERAL(6, 114, 11), // "versionData"
QT_MOC_LITERAL(7, 126, 18), // "headVersionChanged"
QT_MOC_LITERAL(8, 145, 19), // "newHeadVersionIndex"
QT_MOC_LITERAL(9, 165, 10), // "usersAdded"
QT_MOC_LITERAL(10, 176, 13), // "QList<Person>"
QT_MOC_LITERAL(11, 190, 11), // "newUserList"
QT_MOC_LITERAL(12, 202, 12), // "usersRemoved"
QT_MOC_LITERAL(13, 215, 15), // "onModelModified"
QT_MOC_LITERAL(14, 231, 8), // "newState"
QT_MOC_LITERAL(15, 240, 31), // "onHeadVersionDescriptionChanged"
QT_MOC_LITERAL(16, 272, 14) // "newDescription"

    },
    "Kasten::ByteArrayDocument\0"
    "revertedToVersionIndex\0\0versionIndex\0"
    "headVersionDataChanged\0"
    "Kasten::DocumentVersionData\0versionData\0"
    "headVersionChanged\0newHeadVersionIndex\0"
    "usersAdded\0QList<Person>\0newUserList\0"
    "usersRemoved\0onModelModified\0newState\0"
    "onHeadVersionDescriptionChanged\0"
    "newDescription"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__ByteArrayDocument[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       4,    1,   52,    2, 0x06 /* Public */,
       7,    1,   55,    2, 0x06 /* Public */,
       9,    1,   58,    2, 0x06 /* Public */,
      12,    1,   61,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    1,   64,    2, 0x08 /* Private */,
      15,    1,   67,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, QMetaType::QString,   16,

       0        // eod
};

void Kasten::ByteArrayDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ByteArrayDocument *_t = static_cast<ByteArrayDocument *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->revertedToVersionIndex((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->headVersionDataChanged((*reinterpret_cast< const Kasten::DocumentVersionData(*)>(_a[1]))); break;
        case 2: _t->headVersionChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->usersAdded((*reinterpret_cast< const QList<Person>(*)>(_a[1]))); break;
        case 4: _t->usersRemoved((*reinterpret_cast< const QList<Person>(*)>(_a[1]))); break;
        case 5: _t->onModelModified((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->onHeadVersionDescriptionChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ByteArrayDocument::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayDocument::revertedToVersionIndex)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ByteArrayDocument::*_t)(const Kasten::DocumentVersionData & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayDocument::headVersionDataChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ByteArrayDocument::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayDocument::headVersionChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ByteArrayDocument::*_t)(const QList<Person> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayDocument::usersAdded)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ByteArrayDocument::*_t)(const QList<Person> & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayDocument::usersRemoved)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject Kasten::ByteArrayDocument::staticMetaObject = {
    { &AbstractDocument::staticMetaObject, qt_meta_stringdata_Kasten__ByteArrayDocument.data,
      qt_meta_data_Kasten__ByteArrayDocument,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::ByteArrayDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::ByteArrayDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__ByteArrayDocument.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "If::Versionable"))
        return static_cast< If::Versionable*>(this);
    if (!strcmp(_clname, "If::UserListable"))
        return static_cast< If::UserListable*>(this);
    if (!strcmp(_clname, "org.kde.kasten.if.versionable/1.0"))
        return static_cast< Kasten::If::Versionable*>(this);
    if (!strcmp(_clname, "org.kde.kasten.if.userlistable/1.0"))
        return static_cast< Kasten::If::UserListable*>(this);
    return AbstractDocument::qt_metacast(_clname);
}

int Kasten::ByteArrayDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractDocument::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Kasten::ByteArrayDocument::revertedToVersionIndex(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::ByteArrayDocument::headVersionDataChanged(const Kasten::DocumentVersionData & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kasten::ByteArrayDocument::headVersionChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kasten::ByteArrayDocument::usersAdded(const QList<Person> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Kasten::ByteArrayDocument::usersRemoved(const QList<Person> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
