/****************************************************************************
** Meta object code from reading C++ file 'documentinfotool.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/document/info/documentinfotool.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documentinfotool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__DocumentInfoTool_t {
    QByteArrayData data[18];
    char stringdata0[277];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__DocumentInfoTool_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__DocumentInfoTool_t qt_meta_stringdata_Kasten__DocumentInfoTool = {
    {
QT_MOC_LITERAL(0, 0, 24), // "Kasten::DocumentInfoTool"
QT_MOC_LITERAL(1, 25, 20), // "documentTitleChanged"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 13), // "documentTitle"
QT_MOC_LITERAL(4, 61, 23), // "documentMimeTypeChanged"
QT_MOC_LITERAL(5, 85, 9), // "QMimeType"
QT_MOC_LITERAL(6, 95, 8), // "mimeType"
QT_MOC_LITERAL(7, 104, 15), // "locationChanged"
QT_MOC_LITERAL(8, 120, 8), // "location"
QT_MOC_LITERAL(9, 129, 19), // "documentSizeChanged"
QT_MOC_LITERAL(10, 149, 7), // "newSize"
QT_MOC_LITERAL(11, 157, 14), // "updateMimeType"
QT_MOC_LITERAL(12, 172, 17), // "onContentsChanged"
QT_MOC_LITERAL(13, 190, 21), // "onSynchronizerChanged"
QT_MOC_LITERAL(14, 212, 34), // "Kasten::AbstractModelSynchron..."
QT_MOC_LITERAL(15, 247, 12), // "synchronizer"
QT_MOC_LITERAL(16, 260, 12), // "onUrlChanged"
QT_MOC_LITERAL(17, 273, 3) // "url"

    },
    "Kasten::DocumentInfoTool\0documentTitleChanged\0"
    "\0documentTitle\0documentMimeTypeChanged\0"
    "QMimeType\0mimeType\0locationChanged\0"
    "location\0documentSizeChanged\0newSize\0"
    "updateMimeType\0onContentsChanged\0"
    "onSynchronizerChanged\0"
    "Kasten::AbstractModelSynchronizer*\0"
    "synchronizer\0onUrlChanged\0url"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__DocumentInfoTool[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    1,   57,    2, 0x06 /* Public */,
       7,    1,   60,    2, 0x06 /* Public */,
       9,    1,   63,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,   66,    2, 0x08 /* Private */,
      12,    0,   67,    2, 0x08 /* Private */,
      13,    1,   68,    2, 0x08 /* Private */,
      16,    1,   71,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::Int,   10,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, QMetaType::QUrl,   17,

       0        // eod
};

void Kasten::DocumentInfoTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DocumentInfoTool *_t = static_cast<DocumentInfoTool *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->documentTitleChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->documentMimeTypeChanged((*reinterpret_cast< const QMimeType(*)>(_a[1]))); break;
        case 2: _t->locationChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->documentSizeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->updateMimeType(); break;
        case 5: _t->onContentsChanged(); break;
        case 6: _t->onSynchronizerChanged((*reinterpret_cast< Kasten::AbstractModelSynchronizer*(*)>(_a[1]))); break;
        case 7: _t->onUrlChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (DocumentInfoTool::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DocumentInfoTool::documentTitleChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (DocumentInfoTool::*_t)(const QMimeType & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DocumentInfoTool::documentMimeTypeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (DocumentInfoTool::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DocumentInfoTool::locationChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (DocumentInfoTool::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&DocumentInfoTool::documentSizeChanged)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject Kasten::DocumentInfoTool::staticMetaObject = {
    { &AbstractTool::staticMetaObject, qt_meta_stringdata_Kasten__DocumentInfoTool.data,
      qt_meta_data_Kasten__DocumentInfoTool,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::DocumentInfoTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::DocumentInfoTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__DocumentInfoTool.stringdata0))
        return static_cast<void*>(this);
    return AbstractTool::qt_metacast(_clname);
}

int Kasten::DocumentInfoTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTool::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Kasten::DocumentInfoTool::documentTitleChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::DocumentInfoTool::documentMimeTypeChanged(const QMimeType & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kasten::DocumentInfoTool::locationChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kasten::DocumentInfoTool::documentSizeChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
