/****************************************************************************
** Meta object code from reading C++ file 'bookmarklistmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/controllers/view/bookmarks/bookmarklistmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bookmarklistmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__BookmarkListModel_t {
    QByteArrayData data[9];
    char stringdata0[143];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__BookmarkListModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__BookmarkListModel_t qt_meta_stringdata_Kasten__BookmarkListModel = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Kasten::BookmarkListModel"
QT_MOC_LITERAL(1, 26, 21), // "onHasBookmarksChanged"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 12), // "hasBookmarks"
QT_MOC_LITERAL(4, 62, 18), // "onBookmarksChanged"
QT_MOC_LITERAL(5, 81, 10), // "QList<int>"
QT_MOC_LITERAL(6, 92, 15), // "bookmarkIndizes"
QT_MOC_LITERAL(7, 108, 21), // "onOffsetCodingChanged"
QT_MOC_LITERAL(8, 130, 12) // "offsetCoding"

    },
    "Kasten::BookmarkListModel\0"
    "onHasBookmarksChanged\0\0hasBookmarks\0"
    "onBookmarksChanged\0QList<int>\0"
    "bookmarkIndizes\0onOffsetCodingChanged\0"
    "offsetCoding"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__BookmarkListModel[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x08 /* Private */,
       4,    0,   37,    2, 0x08 /* Private */,
       4,    1,   38,    2, 0x08 /* Private */,
       7,    1,   41,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::Int,    8,

       0        // eod
};

void Kasten::BookmarkListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        BookmarkListModel *_t = static_cast<BookmarkListModel *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onHasBookmarksChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->onBookmarksChanged(); break;
        case 2: _t->onBookmarksChanged((*reinterpret_cast< const QList<int>(*)>(_a[1]))); break;
        case 3: _t->onOffsetCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
            }
            break;
        }
    }
}

const QMetaObject Kasten::BookmarkListModel::staticMetaObject = {
    { &QAbstractTableModel::staticMetaObject, qt_meta_stringdata_Kasten__BookmarkListModel.data,
      qt_meta_data_Kasten__BookmarkListModel,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::BookmarkListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::BookmarkListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__BookmarkListModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractTableModel::qt_metacast(_clname);
}

int Kasten::BookmarkListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
