/****************************************************************************
** Meta object code from reading C++ file 'bytearrayviewprofilesynchronizer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/gui/io/bytearrayviewprofilesynchronizer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bytearrayviewprofilesynchronizer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__ByteArrayViewProfileSynchronizer_t {
    QByteArrayData data[26];
    char stringdata0[599];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__ByteArrayViewProfileSynchronizer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__ByteArrayViewProfileSynchronizer_t qt_meta_stringdata_Kasten__ByteArrayViewProfileSynchronizer = {
    {
QT_MOC_LITERAL(0, 0, 40), // "Kasten::ByteArrayViewProfileS..."
QT_MOC_LITERAL(1, 41, 21), // "localSyncStateChanged"
QT_MOC_LITERAL(2, 63, 0), // ""
QT_MOC_LITERAL(3, 64, 22), // "Kasten::LocalSyncState"
QT_MOC_LITERAL(4, 87, 8), // "newState"
QT_MOC_LITERAL(5, 96, 18), // "viewProfileChanged"
QT_MOC_LITERAL(6, 115, 32), // "Kasten::ByteArrayViewProfile::Id"
QT_MOC_LITERAL(7, 148, 13), // "viewProfileId"
QT_MOC_LITERAL(8, 162, 21), // "onViewProfilesChanged"
QT_MOC_LITERAL(9, 184, 35), // "QList<Kasten::ByteArrayViewPr..."
QT_MOC_LITERAL(10, 220, 12), // "viewProfiles"
QT_MOC_LITERAL(11, 233, 21), // "onViewProfilesRemoved"
QT_MOC_LITERAL(12, 255, 39), // "QList<Kasten::ByteArrayViewPr..."
QT_MOC_LITERAL(13, 295, 14), // "viewProfileIds"
QT_MOC_LITERAL(14, 310, 25), // "onShowsNonprintingChanged"
QT_MOC_LITERAL(15, 336, 21), // "onOffsetCodingChanged"
QT_MOC_LITERAL(16, 358, 20), // "onValueCodingChanged"
QT_MOC_LITERAL(17, 379, 18), // "onCharCodecChanged"
QT_MOC_LITERAL(18, 398, 23), // "onSubstituteCharChanged"
QT_MOC_LITERAL(19, 422, 22), // "onUndefinedCharChanged"
QT_MOC_LITERAL(20, 445, 32), // "onVisibleByteArrayCodingsChanged"
QT_MOC_LITERAL(21, 478, 28), // "onOffsetColumnVisibleChanged"
QT_MOC_LITERAL(22, 507, 25), // "onNoOfBytesPerLineChanged"
QT_MOC_LITERAL(23, 533, 25), // "onNoOfGroupedBytesChanged"
QT_MOC_LITERAL(24, 559, 20), // "onLayoutStyleChanged"
QT_MOC_LITERAL(25, 580, 18) // "onViewModusChanged"

    },
    "Kasten::ByteArrayViewProfileSynchronizer\0"
    "localSyncStateChanged\0\0Kasten::LocalSyncState\0"
    "newState\0viewProfileChanged\0"
    "Kasten::ByteArrayViewProfile::Id\0"
    "viewProfileId\0onViewProfilesChanged\0"
    "QList<Kasten::ByteArrayViewProfile>\0"
    "viewProfiles\0onViewProfilesRemoved\0"
    "QList<Kasten::ByteArrayViewProfile::Id>\0"
    "viewProfileIds\0onShowsNonprintingChanged\0"
    "onOffsetCodingChanged\0onValueCodingChanged\0"
    "onCharCodecChanged\0onSubstituteCharChanged\0"
    "onUndefinedCharChanged\0"
    "onVisibleByteArrayCodingsChanged\0"
    "onOffsetColumnVisibleChanged\0"
    "onNoOfBytesPerLineChanged\0"
    "onNoOfGroupedBytesChanged\0"
    "onLayoutStyleChanged\0onViewModusChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__ByteArrayViewProfileSynchronizer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x06 /* Public */,
       5,    1,   97,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,  100,    2, 0x08 /* Private */,
      11,    1,  103,    2, 0x08 /* Private */,
      14,    0,  106,    2, 0x08 /* Private */,
      15,    0,  107,    2, 0x08 /* Private */,
      16,    0,  108,    2, 0x08 /* Private */,
      17,    0,  109,    2, 0x08 /* Private */,
      18,    0,  110,    2, 0x08 /* Private */,
      19,    0,  111,    2, 0x08 /* Private */,
      20,    0,  112,    2, 0x08 /* Private */,
      21,    0,  113,    2, 0x08 /* Private */,
      22,    0,  114,    2, 0x08 /* Private */,
      23,    0,  115,    2, 0x08 /* Private */,
      24,    0,  116,    2, 0x08 /* Private */,
      25,    0,  117,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Kasten::ByteArrayViewProfileSynchronizer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ByteArrayViewProfileSynchronizer *_t = static_cast<ByteArrayViewProfileSynchronizer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->localSyncStateChanged((*reinterpret_cast< Kasten::LocalSyncState(*)>(_a[1]))); break;
        case 1: _t->viewProfileChanged((*reinterpret_cast< const Kasten::ByteArrayViewProfile::Id(*)>(_a[1]))); break;
        case 2: _t->onViewProfilesChanged((*reinterpret_cast< const QList<Kasten::ByteArrayViewProfile>(*)>(_a[1]))); break;
        case 3: _t->onViewProfilesRemoved((*reinterpret_cast< const QList<Kasten::ByteArrayViewProfile::Id>(*)>(_a[1]))); break;
        case 4: _t->onShowsNonprintingChanged(); break;
        case 5: _t->onOffsetCodingChanged(); break;
        case 6: _t->onValueCodingChanged(); break;
        case 7: _t->onCharCodecChanged(); break;
        case 8: _t->onSubstituteCharChanged(); break;
        case 9: _t->onUndefinedCharChanged(); break;
        case 10: _t->onVisibleByteArrayCodingsChanged(); break;
        case 11: _t->onOffsetColumnVisibleChanged(); break;
        case 12: _t->onNoOfBytesPerLineChanged(); break;
        case 13: _t->onNoOfGroupedBytesChanged(); break;
        case 14: _t->onLayoutStyleChanged(); break;
        case 15: _t->onViewModusChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ByteArrayViewProfileSynchronizer::*_t)(Kasten::LocalSyncState );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayViewProfileSynchronizer::localSyncStateChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ByteArrayViewProfileSynchronizer::*_t)(const Kasten::ByteArrayViewProfile::Id & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayViewProfileSynchronizer::viewProfileChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Kasten::ByteArrayViewProfileSynchronizer::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Kasten__ByteArrayViewProfileSynchronizer.data,
      qt_meta_data_Kasten__ByteArrayViewProfileSynchronizer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::ByteArrayViewProfileSynchronizer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::ByteArrayViewProfileSynchronizer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__ByteArrayViewProfileSynchronizer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kasten::ByteArrayViewProfileSynchronizer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Kasten::ByteArrayViewProfileSynchronizer::localSyncStateChanged(Kasten::LocalSyncState _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Kasten::ByteArrayViewProfileSynchronizer::viewProfileChanged(const Kasten::ByteArrayViewProfile::Id & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
