/****************************************************************************
** Meta object code from reading C++ file 'shellwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/okteta-17.08.3/libs/kasten/gui/shell/shellwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'shellwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kasten__ShellWindow_t {
    QByteArrayData data[20];
    char stringdata0[320];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kasten__ShellWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kasten__ShellWindow_t qt_meta_stringdata_Kasten__ShellWindow = {
    {
QT_MOC_LITERAL(0, 0, 19), // "Kasten::ShellWindow"
QT_MOC_LITERAL(1, 20, 12), // "showDocument"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 25), // "Kasten::AbstractDocument*"
QT_MOC_LITERAL(4, 60, 8), // "document"
QT_MOC_LITERAL(5, 69, 14), // "onTitleChanged"
QT_MOC_LITERAL(6, 84, 8), // "newTitle"
QT_MOC_LITERAL(7, 93, 21), // "onContentFlagsChanged"
QT_MOC_LITERAL(8, 115, 20), // "Kasten::ContentFlags"
QT_MOC_LITERAL(9, 136, 12), // "contentFlags"
QT_MOC_LITERAL(10, 149, 23), // "onLocalSyncStateChanged"
QT_MOC_LITERAL(11, 173, 22), // "Kasten::LocalSyncState"
QT_MOC_LITERAL(12, 196, 8), // "newState"
QT_MOC_LITERAL(13, 205, 18), // "onViewFocusChanged"
QT_MOC_LITERAL(14, 224, 21), // "Kasten::AbstractView*"
QT_MOC_LITERAL(15, 246, 4), // "view"
QT_MOC_LITERAL(16, 251, 23), // "onToolVisibilityChanged"
QT_MOC_LITERAL(17, 275, 9), // "isVisible"
QT_MOC_LITERAL(18, 285, 21), // "onSynchronizerDeleted"
QT_MOC_LITERAL(19, 307, 12) // "synchronizer"

    },
    "Kasten::ShellWindow\0showDocument\0\0"
    "Kasten::AbstractDocument*\0document\0"
    "onTitleChanged\0newTitle\0onContentFlagsChanged\0"
    "Kasten::ContentFlags\0contentFlags\0"
    "onLocalSyncStateChanged\0Kasten::LocalSyncState\0"
    "newState\0onViewFocusChanged\0"
    "Kasten::AbstractView*\0view\0"
    "onToolVisibilityChanged\0isVisible\0"
    "onSynchronizerDeleted\0synchronizer"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kasten__ShellWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x0a /* Public */,
       5,    1,   52,    2, 0x08 /* Private */,
       7,    1,   55,    2, 0x08 /* Private */,
      10,    1,   58,    2, 0x08 /* Private */,
      13,    1,   61,    2, 0x08 /* Private */,
      16,    1,   64,    2, 0x08 /* Private */,
      18,    1,   67,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void, QMetaType::QObjectStar,   19,

       0        // eod
};

void Kasten::ShellWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ShellWindow *_t = static_cast<ShellWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->showDocument((*reinterpret_cast< Kasten::AbstractDocument*(*)>(_a[1]))); break;
        case 1: _t->d_func()->onTitleChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->d_func()->onContentFlagsChanged((*reinterpret_cast< Kasten::ContentFlags(*)>(_a[1]))); break;
        case 3: _t->d_func()->onLocalSyncStateChanged((*reinterpret_cast< Kasten::LocalSyncState(*)>(_a[1]))); break;
        case 4: _t->d_func()->onViewFocusChanged((*reinterpret_cast< Kasten::AbstractView*(*)>(_a[1]))); break;
        case 5: _t->d_func()->onToolVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->d_func()->onSynchronizerDeleted((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject Kasten::ShellWindow::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_Kasten__ShellWindow.data,
      qt_meta_data_Kasten__ShellWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kasten::ShellWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kasten::ShellWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kasten__ShellWindow.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "If::WidgetsDockable"))
        return static_cast< If::WidgetsDockable*>(this);
    if (!strcmp(_clname, "org.kde.kasten.if.widgetsdockable/1.0"))
        return static_cast< Kasten::If::WidgetsDockable*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Kasten::ShellWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
