/****************************************************************************
** Meta object code from reading C++ file 'bytearrayjanusview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/okteta-17.08.3/kasten/gui/view/bytearrayjanusview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bytearrayjanusview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Okteta__ByteArrayJanusView_t {
    QByteArrayData data[41];
    char stringdata0[687];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Okteta__ByteArrayJanusView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Okteta__ByteArrayJanusView_t qt_meta_stringdata_Okteta__ByteArrayJanusView = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Okteta::ByteArrayJanusView"
QT_MOC_LITERAL(1, 27, 15), // "readOnlyChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 20), // "overwriteModeChanged"
QT_MOC_LITERAL(4, 65, 13), // "overwriteMode"
QT_MOC_LITERAL(5, 79, 22), // "hasSelectedDataChanged"
QT_MOC_LITERAL(6, 102, 15), // "hasSelectedData"
QT_MOC_LITERAL(7, 118, 16), // "selectionChanged"
QT_MOC_LITERAL(8, 135, 20), // "Okteta::AddressRange"
QT_MOC_LITERAL(9, 156, 9), // "selection"
QT_MOC_LITERAL(10, 166, 21), // "cursorPositionChanged"
QT_MOC_LITERAL(11, 188, 15), // "Okteta::Address"
QT_MOC_LITERAL(12, 204, 14), // "cursorPosition"
QT_MOC_LITERAL(13, 219, 18), // "valueCodingChanged"
QT_MOC_LITERAL(14, 238, 11), // "valueCoding"
QT_MOC_LITERAL(15, 250, 16), // "charCodecChanged"
QT_MOC_LITERAL(16, 267, 14), // "charCodingName"
QT_MOC_LITERAL(17, 282, 12), // "focusChanged"
QT_MOC_LITERAL(18, 295, 8), // "hasFocus"
QT_MOC_LITERAL(19, 304, 26), // "offsetColumnVisibleChanged"
QT_MOC_LITERAL(20, 331, 7), // "visible"
QT_MOC_LITERAL(21, 339, 19), // "offsetCodingChanged"
QT_MOC_LITERAL(22, 359, 12), // "offsetCoding"
QT_MOC_LITERAL(23, 372, 30), // "visibleByteArrayCodingsChanged"
QT_MOC_LITERAL(24, 403, 7), // "columns"
QT_MOC_LITERAL(25, 411, 18), // "layoutStyleChanged"
QT_MOC_LITERAL(26, 430, 11), // "layoutStyle"
QT_MOC_LITERAL(27, 442, 23), // "noOfBytesPerLineChanged"
QT_MOC_LITERAL(28, 466, 16), // "noOfBytesPerLine"
QT_MOC_LITERAL(29, 483, 23), // "showsNonprintingChanged"
QT_MOC_LITERAL(30, 507, 16), // "showsNonprinting"
QT_MOC_LITERAL(31, 524, 21), // "substituteCharChanged"
QT_MOC_LITERAL(32, 546, 14), // "substituteChar"
QT_MOC_LITERAL(33, 561, 20), // "undefinedCharChanged"
QT_MOC_LITERAL(34, 582, 13), // "undefinedChar"
QT_MOC_LITERAL(35, 596, 23), // "noOfGroupedBytesChanged"
QT_MOC_LITERAL(36, 620, 16), // "noOfGroupedBytes"
QT_MOC_LITERAL(37, 637, 16), // "zoomLevelChanged"
QT_MOC_LITERAL(38, 654, 5), // "level"
QT_MOC_LITERAL(39, 660, 16), // "viewModusChanged"
QT_MOC_LITERAL(40, 677, 9) // "viewModus"

    },
    "Okteta::ByteArrayJanusView\0readOnlyChanged\0"
    "\0overwriteModeChanged\0overwriteMode\0"
    "hasSelectedDataChanged\0hasSelectedData\0"
    "selectionChanged\0Okteta::AddressRange\0"
    "selection\0cursorPositionChanged\0"
    "Okteta::Address\0cursorPosition\0"
    "valueCodingChanged\0valueCoding\0"
    "charCodecChanged\0charCodingName\0"
    "focusChanged\0hasFocus\0offsetColumnVisibleChanged\0"
    "visible\0offsetCodingChanged\0offsetCoding\0"
    "visibleByteArrayCodingsChanged\0columns\0"
    "layoutStyleChanged\0layoutStyle\0"
    "noOfBytesPerLineChanged\0noOfBytesPerLine\0"
    "showsNonprintingChanged\0showsNonprinting\0"
    "substituteCharChanged\0substituteChar\0"
    "undefinedCharChanged\0undefinedChar\0"
    "noOfGroupedBytesChanged\0noOfGroupedBytes\0"
    "zoomLevelChanged\0level\0viewModusChanged\0"
    "viewModus"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Okteta__ByteArrayJanusView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      19,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  109,    2, 0x06 /* Public */,
       3,    1,  112,    2, 0x06 /* Public */,
       5,    1,  115,    2, 0x06 /* Public */,
       7,    1,  118,    2, 0x06 /* Public */,
      10,    1,  121,    2, 0x06 /* Public */,
      13,    1,  124,    2, 0x06 /* Public */,
      15,    1,  127,    2, 0x06 /* Public */,
      17,    1,  130,    2, 0x06 /* Public */,
      19,    1,  133,    2, 0x06 /* Public */,
      21,    1,  136,    2, 0x06 /* Public */,
      23,    1,  139,    2, 0x06 /* Public */,
      25,    1,  142,    2, 0x06 /* Public */,
      27,    1,  145,    2, 0x06 /* Public */,
      29,    1,  148,    2, 0x06 /* Public */,
      31,    1,  151,    2, 0x06 /* Public */,
      33,    1,  154,    2, 0x06 /* Public */,
      35,    1,  157,    2, 0x06 /* Public */,
      37,    1,  160,    2, 0x06 /* Public */,
      39,    1,  163,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::Int,   24,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void, QMetaType::Int,   28,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::QChar,   32,
    QMetaType::Void, QMetaType::QChar,   34,
    QMetaType::Void, QMetaType::Int,   36,
    QMetaType::Void, QMetaType::Double,   38,
    QMetaType::Void, QMetaType::Int,   40,

       0        // eod
};

void Okteta::ByteArrayJanusView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ByteArrayJanusView *_t = static_cast<ByteArrayJanusView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->readOnlyChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->overwriteModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->hasSelectedDataChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->selectionChanged((*reinterpret_cast< const Okteta::AddressRange(*)>(_a[1]))); break;
        case 4: _t->cursorPositionChanged((*reinterpret_cast< Okteta::Address(*)>(_a[1]))); break;
        case 5: _t->valueCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->charCodecChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->focusChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->offsetColumnVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->offsetCodingChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->visibleByteArrayCodingsChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->layoutStyleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->noOfBytesPerLineChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->showsNonprintingChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->substituteCharChanged((*reinterpret_cast< QChar(*)>(_a[1]))); break;
        case 15: _t->undefinedCharChanged((*reinterpret_cast< QChar(*)>(_a[1]))); break;
        case 16: _t->noOfGroupedBytesChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->zoomLevelChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 18: _t->viewModusChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (ByteArrayJanusView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::readOnlyChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::overwriteModeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::hasSelectedDataChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(const Okteta::AddressRange & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::selectionChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(Okteta::Address );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::cursorPositionChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::valueCodingChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::charCodecChanged)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::focusChanged)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::offsetColumnVisibleChanged)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::offsetCodingChanged)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::visibleByteArrayCodingsChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::layoutStyleChanged)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::noOfBytesPerLineChanged)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::showsNonprintingChanged)) {
                *result = 13;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(QChar );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::substituteCharChanged)) {
                *result = 14;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(QChar );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::undefinedCharChanged)) {
                *result = 15;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::noOfGroupedBytesChanged)) {
                *result = 16;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(double );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::zoomLevelChanged)) {
                *result = 17;
                return;
            }
        }
        {
            typedef void (ByteArrayJanusView::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&ByteArrayJanusView::viewModusChanged)) {
                *result = 18;
                return;
            }
        }
    }
}

const QMetaObject Okteta::ByteArrayJanusView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Okteta__ByteArrayJanusView.data,
      qt_meta_data_Okteta__ByteArrayJanusView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Okteta::ByteArrayJanusView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Okteta::ByteArrayJanusView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Okteta__ByteArrayJanusView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Okteta::ByteArrayJanusView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void Okteta::ByteArrayJanusView::readOnlyChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Okteta::ByteArrayJanusView::overwriteModeChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Okteta::ByteArrayJanusView::hasSelectedDataChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Okteta::ByteArrayJanusView::selectionChanged(const Okteta::AddressRange & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Okteta::ByteArrayJanusView::cursorPositionChanged(Okteta::Address _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Okteta::ByteArrayJanusView::valueCodingChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Okteta::ByteArrayJanusView::charCodecChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Okteta::ByteArrayJanusView::focusChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Okteta::ByteArrayJanusView::offsetColumnVisibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Okteta::ByteArrayJanusView::offsetCodingChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Okteta::ByteArrayJanusView::visibleByteArrayCodingsChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Okteta::ByteArrayJanusView::layoutStyleChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Okteta::ByteArrayJanusView::noOfBytesPerLineChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Okteta::ByteArrayJanusView::showsNonprintingChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Okteta::ByteArrayJanusView::substituteCharChanged(QChar _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Okteta::ByteArrayJanusView::undefinedCharChanged(QChar _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Okteta::ByteArrayJanusView::noOfGroupedBytesChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void Okteta::ByteArrayJanusView::zoomLevelChanged(double _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void Okteta::ByteArrayJanusView::viewModusChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
